@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003 - 2012 by Claude Bulin
+ * copyright : (C) 2003 - 2013 by Claude Bulin
  *
  * xcfa - Creation d'une base de programmation en langage C de type GNU avec les autotools
  * GNU General Public License
@@ -430,32 +430,31 @@ GdkPixbuf *libutils_init_pixbufs (gchar *NameFilePixbuf)
 	return (NewPixbuf);
 }
 // 
+// typedef enum {
+// 	TYPE_ALL_FILE = 0,
+// 	TYPE_WAV_FILE,
+// 	TYPE_MP3_OGG_FILE,
+// 	TYPE_TAG_FILE 
+// } TYPE_FILE;
 // 
-gint *libutils_get_tab_selected_line (GtkTreeSelection *AdrLine, GtkTreeModel *AdrTreeModel)
+gint libutils_get_first_line_is_selected( GtkTreeSelection *AdrLine, GtkTreeModel *AdrTreeModel )
 {
-	guint		NbSelect;
-	guint		tt = 0;
 	gboolean	valid;
 	GtkTreeIter	iter;
-	gint		*TabInt = NULL;
-	gint		Cpt = 0;
+	gint		Cpt = -1;
 	
-	if (NULL != AdrLine) {
-		if ((NbSelect = gtk_tree_selection_count_selected_rows (AdrLine)) > 0) {
-			TabInt = (gint *)g_malloc0 (sizeof (gint) * (NbSelect + 10));
-			valid = gtk_tree_model_get_iter_first (AdrTreeModel, &iter);
-			while (valid) {
-				if (TRUE == gtk_tree_selection_iter_is_selected (AdrLine, &iter)) {
-					*(TabInt + Cpt) = tt;
-					Cpt ++;
-				}
-				tt ++;
-				valid = gtk_tree_model_iter_next (AdrTreeModel, &iter);
+	if (NULL != AdrLine && NULL != AdrTreeModel ) {
+		valid = gtk_tree_model_get_iter_first( AdrTreeModel, &iter );
+		while (valid) {
+			if (TRUE == gtk_tree_selection_iter_is_selected( AdrLine, &iter) ) {
+				Cpt ++;
+				return( Cpt );
 			}
-			*(TabInt + Cpt) = -1;
+			valid = gtk_tree_model_iter_next( AdrTreeModel, &iter );
+			if( TRUE == valid ) Cpt ++;
 		}
 	}
-	return ((gint *)TabInt);
+	return( -1 );
 }
 // 
 // 
