@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003 - 2012 by Claude Bulin
+ * copyright : (C) 2003 - 2013 by Claude Bulin
  *
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
@@ -90,7 +90,7 @@ gboolean	libutils_test_write (gchar *path);
 GdkPixbuf	*libutils_init_pixbufs (gchar *NameFilePixbuf);
 gchar		*libutils_get_pathname_with_new_ext (gchar *PathName, gchar *NewExt);
 gboolean	libutils_test_file_with_new_ext_exist (gchar *PathName, gchar *NewExt);
-gint		*libutils_get_tab_selected_line (GtkTreeSelection *AdrLine, GtkTreeModel *AdrTreeModel);
+gint		libutils_get_first_line_is_selected( GtkTreeSelection *AdrLine, GtkTreeModel *AdrTreeModel );
 gchar		*libutils_get_name_without_ext_with_amp( gchar *p_PathNameFile );
 gchar		*libutils_get_name_without_ext( gchar *p_PathNameFile );
 gchar		*libutils_create_temporary_rep (gchar *SrcTmp, gchar *NewRepTmp);
