@@ -173,19 +173,19 @@ void cdaudioextract_remove_list (void)
 }
 // SAUVEGARDE DES POINTEURS
 // 
-void cdaudioextract_save_arg_from_conv (CD_AUDIO *Audio, gint p_Num)
+void cdaudioextract_save_arg_from_conv( gchar **p_PtrTabArgs, CD_AUDIO *Audio, gint p_Num)
 {
 	gint	Pos;
 
-	for (Pos = 0; NULL != conv.ArgConv [ Pos ]; Pos ++) {
-		Audio->ListConv[ p_Num ].Arg [ Pos ] = conv.ArgConv [ Pos ];
-		conv.ArgConv [ Pos ] = NULL;
+	for (Pos = 0; NULL != p_PtrTabArgs [ Pos ]; Pos ++) {
+		Audio->ListConv[ p_Num ].Arg [ Pos ] = p_PtrTabArgs [ Pos ];
+		p_PtrTabArgs [ Pos ] = NULL;
 	}
 	Audio->ListConv[ p_Num ].Arg [ Pos ] = NULL;
 }
 // 
 // 
-void cdaudioextract_save_arg_from_extract (CD_AUDIO *Audio, gint p_Num)
+void cdaudioextract_save_arg_from_extract( CD_AUDIO *Audio, gint p_Num)
 {
 	gint	Pos;
 
@@ -197,15 +197,15 @@ void cdaudioextract_save_arg_from_extract (CD_AUDIO *Audio, gint p_Num)
 }
 // RESTITUTION DES POINTEURS
 // 
-void cdaudioextract_restitue_arg_to_conv (CD_AUDIO *Audio, gint p_Num)
+void cdaudioextract_restitue_arg_to_conv( gchar **p_PtrTabArgs, CD_AUDIO *Audio, gint p_Num )
 {
 	gint	Pos;
 
 	for (Pos = 0; NULL != Audio->ListConv[ p_Num ].Arg [ Pos ]; Pos ++) {
-		conv.ArgConv [ Pos ] = Audio->ListConv[ p_Num ].Arg [ Pos ];
+		p_PtrTabArgs [ Pos ] = Audio->ListConv[ p_Num ].Arg [ Pos ];
 		Audio->ListConv[ p_Num ].Arg [ Pos ] = NULL;
 	}
-	conv.ArgConv [ Pos ] = NULL;
+	p_PtrTabArgs [ Pos ] = NULL;
 }
 // 
 // 
@@ -226,6 +226,7 @@ void cdaudioextract_create_list_is_Convert (void)
 	GList		*List = NULL;
 	CD_AUDIO	*Audio = NULL;
 	PARAM_FILELC	 param_filelc;
+	gchar		**PtrTabArgs = NULL;
 	
 	List = g_list_first (EnteteCD.GList_Audio_cd);
 	while (List) {
@@ -288,8 +289,9 @@ void cdaudioextract_create_list_is_Convert (void)
 				param_filelc.PtrStrBitrate         = NULL;
 				
 				Audio->ListConv[ NUM_FLAC ].WithCommandLineUser = param_filelc.With_CommandLineUser;
-				filelc_get_command_line (&param_filelc);
-				cdaudioextract_save_arg_from_conv (Audio, NUM_FLAC);
+				PtrTabArgs = filelc_get_command_line (&param_filelc);
+				cdaudioextract_save_arg_from_conv( PtrTabArgs, Audio, NUM_FLAC );
+				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 			}
 			if (Audio->Etat_Ape == ETAT_CONV_CD_WAITING) {
 				param_filelc.type_conv             = MAC_WAV_TO_APE;
@@ -303,8 +305,9 @@ void cdaudioextract_create_list_is_Convert (void)
 				param_filelc.PtrStrBitrate         = NULL;
 				
 				Audio->ListConv[ NUM_APE ].WithCommandLineUser = param_filelc.With_CommandLineUser;
-				filelc_get_command_line (&param_filelc);
-				cdaudioextract_save_arg_from_conv (Audio, NUM_APE);
+				PtrTabArgs = filelc_get_command_line (&param_filelc);
+				cdaudioextract_save_arg_from_conv (PtrTabArgs, Audio, NUM_APE);
+				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 			}
 			if (Audio->Etat_WavPack == ETAT_CONV_CD_WAITING) {
 				param_filelc.type_conv             = WAVPACK_WAV_TO_WAVPACK;
@@ -318,8 +321,9 @@ void cdaudioextract_create_list_is_Convert (void)
 				param_filelc.PtrStrBitrate         = NULL;
 
 				Audio->ListConv[ NUM_WAVPACK ].WithCommandLineUser = param_filelc.With_CommandLineUser;
-				filelc_get_command_line (&param_filelc);
-				cdaudioextract_save_arg_from_conv (Audio, NUM_WAVPACK);
+				PtrTabArgs = filelc_get_command_line (&param_filelc);
+				cdaudioextract_save_arg_from_conv (PtrTabArgs, Audio, NUM_WAVPACK);
+				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 			}
 			if (Audio->Etat_Sox == ETAT_CONV_CD_WAITING || Audio->Etat_Ogg == ETAT_CONV_CD_WAITING) {
 				param_filelc.type_conv             = OGGENC_WAV_TO_OGG;
@@ -341,8 +345,9 @@ void cdaudioextract_create_list_is_Convert (void)
 				param_filelc.PtrStrBitrate         = options_get_params (OGGENC_WAV_TO_OGG);
 
 				Audio->ListConv[ NUM_OGG ].WithCommandLineUser = param_filelc.With_CommandLineUser;
-				filelc_get_command_line (&param_filelc);
-				cdaudioextract_save_arg_from_conv (Audio, NUM_OGG);
+				PtrTabArgs = filelc_get_command_line (&param_filelc);
+				cdaudioextract_save_arg_from_conv (PtrTabArgs, Audio, NUM_OGG);
+				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 			}
 			if (Audio->Etat_m4a == ETAT_CONV_CD_WAITING) {
 				param_filelc.type_conv             = FAAC_WAV_TO_M4A;
@@ -356,8 +361,9 @@ void cdaudioextract_create_list_is_Convert (void)
 				param_filelc.PtrStrBitrate         = NULL;
 
 				Audio->ListConv[ NUM_M4A ].WithCommandLineUser = param_filelc.With_CommandLineUser;
-				filelc_get_command_line (&param_filelc);
-				cdaudioextract_save_arg_from_conv (Audio, NUM_M4A);
+				PtrTabArgs = filelc_get_command_line (&param_filelc);
+				cdaudioextract_save_arg_from_conv (PtrTabArgs, Audio, NUM_M4A);
+				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 			}
 			if (Audio->Etat_Aac == ETAT_CONV_CD_WAITING) {
 				param_filelc.type_conv             = AACPLUSENC_WAV_TO_AAC;
@@ -372,8 +378,9 @@ void cdaudioextract_create_list_is_Convert (void)
 				param_filelc.PtrStrBitrate         = options_get_params (AACPLUSENC_WAV_TO_AAC);
 
 				Audio->ListConv[ NUM_AAC ].WithCommandLineUser = param_filelc.With_CommandLineUser;
-				filelc_get_command_line (&param_filelc);
-				cdaudioextract_save_arg_from_conv (Audio, NUM_AAC);
+				PtrTabArgs = filelc_get_command_line (&param_filelc);
+				cdaudioextract_save_arg_from_conv (PtrTabArgs, Audio, NUM_AAC);
+				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 			}
 			if (Audio->Etat_Sox == ETAT_CONV_CD_WAITING || Audio->Etat_Mpc == ETAT_CONV_CD_WAITING) {
 				param_filelc.type_conv             = MPPENC_WAV_TO_MPC;
@@ -394,8 +401,9 @@ void cdaudioextract_create_list_is_Convert (void)
 				param_filelc.PtrStrBitrate         = NULL;
 
 				Audio->ListConv[ NUM_MPC ].WithCommandLineUser = param_filelc.With_CommandLineUser;
-				filelc_get_command_line (&param_filelc);
-				cdaudioextract_save_arg_from_conv (Audio, NUM_MPC);
+				PtrTabArgs = filelc_get_command_line (&param_filelc);
+				cdaudioextract_save_arg_from_conv (PtrTabArgs, Audio, NUM_MPC);
+				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 			}
 			if (Audio->Etat_Mp3 == ETAT_CONV_CD_WAITING) {
 				param_filelc.type_conv             = LAME_WAV_TO_MP3;
@@ -410,8 +418,9 @@ void cdaudioextract_create_list_is_Convert (void)
 				param_filelc.PtrStrBitrate         = options_get_params (LAME_WAV_TO_MP3);
 
 				Audio->ListConv[ NUM_MP3 ].WithCommandLineUser = param_filelc.With_CommandLineUser;
-				filelc_get_command_line (&param_filelc);
-				cdaudioextract_save_arg_from_conv (Audio, NUM_MP3);
+				PtrTabArgs = filelc_get_command_line (&param_filelc);
+				cdaudioextract_save_arg_from_conv (PtrTabArgs, Audio, NUM_MP3);
+				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 			}
 		}
 		List = g_list_next(List);
@@ -498,7 +507,6 @@ gboolean cdaudioextract_create_list_is_Extract (void)
 					Audio->ListConv[ NUM_WAV ].WithCommandLineUser = param_filelc.With_CommandLineUser;
 					filelc_get_command_line_extract (&param_filelc);
 					cdaudioextract_save_arg_from_extract (Audio, NUM_WAV);
-					
 					break;
 				case EXTRACT_WITH_CDPARANOIA_EXPERT :
 					
@@ -875,6 +883,7 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 			
 			GList				*List2 = NULL;
 			VAR_CD_NORMALISE_ELEMENT	*VarCDNormaliseElement = NULL;
+			gchar				**PtrTabArgs = NULL;
 			
 			// COPIE DES FICHIERS DESTINAION -> TEMPORAIRE
 			
@@ -888,48 +897,50 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 			
 			// -- CHERCHER LA MOYENNE PEAK
 			
-			pos = filelc_get_command_line_nice ();
-			conv.ArgConv [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
-			conv.ArgConv [ pos++ ] = g_strdup ("-n");
+			PtrTabArgs = filelc_AllocTabArgs();
+			pos = 3;
+			PtrTabArgs [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
+			PtrTabArgs [ pos++ ] = g_strdup ("-n");
 			
 			// -- AJOUTER LA LISTE DES FICHIERS
 
 			List2 = g_list_first (CdNormalise_get_list_PeakGroup ());
 			while (List2) {
 				if (NULL != (VarCDNormaliseElement = (VAR_CD_NORMALISE_ELEMENT *)List2->data)) {
-					conv.ArgConv [ pos++ ] = g_strdup_printf ("%s", VarCDNormaliseElement->PathNameSrc);
+					PtrTabArgs [ pos++ ] = g_strdup_printf ("%s", VarCDNormaliseElement->PathNameSrc);
 				}
 				List2 = g_list_next(List2);
 			}
-			conv.ArgConv [ pos++ ] = NULL;
+			PtrTabArgs [ pos++ ] = NULL;
 			
 			conv.bool_percent_extract = conv.bool_percent_conv = TRUE;
-			conv_to_convert (FALSE, NORMALISE_GET_LEVEL, "NORMALISE_GET_LEVEL -> PEAK/GROUP");
-			filelc_get_command_line_remove ();
+			conv_to_convert (PtrTabArgs, FALSE, NORMALISE_GET_LEVEL, "NORMALISE_GET_LEVEL -> PEAK/GROUP");
+			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 			
 			// -- APPLIQUER LA MOYENNE PEAK
 			if (FALSE == conv.bool_stop) {
-				pos = filelc_get_command_line_nice ();
-				conv.ArgConv [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
-				conv.ArgConv [ pos++ ] = g_strdup_printf ("--gain=%fdB", conv.value_PEAK_RMS_GROUP_ARGS);
+				PtrTabArgs = filelc_AllocTabArgs();
+				pos = 3;
+				PtrTabArgs [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
+				PtrTabArgs [ pos++ ] = g_strdup_printf ("--gain=%fdB", conv.value_PEAK_RMS_GROUP_ARGS);
 							
 				// -- AJOUTER LA LISTE DES FICHIERS
 				
 				List2 = g_list_first (CdNormalise_get_list_PeakGroup ());
 				while (List2) {
 					if (NULL != (VarCDNormaliseElement = (VAR_CD_NORMALISE_ELEMENT *)List2->data)) {
-						conv.ArgConv [ pos++ ] = g_strdup_printf ("%s", VarCDNormaliseElement->PathNameSrc);
+						PtrTabArgs [ pos++ ] = g_strdup_printf ("%s", VarCDNormaliseElement->PathNameSrc);
 					}
 					List2 = g_list_next(List2);
 				}
-				conv.ArgConv [ pos++ ] = g_strdup ("--");
-				conv.ArgConv [ pos++ ] = NULL;
+				PtrTabArgs [ pos++ ] = g_strdup ("--");
+				PtrTabArgs [ pos++ ] = NULL;
 				
 				// -- NORMALISATION
 				
 				conv.bool_percent_extract = conv.bool_percent_conv = TRUE;
-				conv_to_convert (FALSE, NORMALISE_EXEC, "NORMALISE_EXEC Wav -> PEAK/GROUP");
-				filelc_get_command_line_remove ();
+				conv_to_convert (PtrTabArgs, FALSE, NORMALISE_EXEC, "NORMALISE_EXEC Wav -> PEAK/GROUP");
+				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 
 				CdNormalise_set_normalise_ok ();
 
@@ -967,6 +978,7 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 	GList		*ListOne = NULL;
 	CD_AUDIO	*Audio = NULL;
 	gint		pos;
+	gchar		**PtrTabArgs = NULL;
 	
 	conv.bool_thread_conv = TRUE;
 	
@@ -1000,11 +1012,13 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 				
 				gchar	*Name = NULL;
 				gchar	*Ptr = NULL;
+				gchar	**PtrTabArgs = NULL;
 
 				// Creation de la list
-				pos = filelc_get_command_line_nice ();
-				conv.ArgConv [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
-				conv.ArgConv [ pos++ ] = g_strdup ("--peak");
+				PtrTabArgs = filelc_AllocTabArgs();
+				pos = 3;
+				PtrTabArgs [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
+				PtrTabArgs [ pos++ ] = g_strdup ("--peak");
 								
 				Name = g_strdup_printf ("%s0123456789", Audio->PathName_Dest_Wav);
 				Ptr = strrchr (Name, '/');
@@ -1012,13 +1026,13 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 				strcpy (Ptr, "01.wav");
 				conv_copy_src_to_dest (Audio->PathName_Dest_Wav, Name);
 				
-				conv.ArgConv [ pos++ ] = g_strdup_printf ("%s", Name);
-				conv.ArgConv [ pos++ ] = g_strdup ("--");
-				conv.ArgConv [ pos++ ] = NULL;
+				PtrTabArgs [ pos++ ] = g_strdup_printf ("%s", Name);
+				PtrTabArgs [ pos++ ] = g_strdup ("--");
+				PtrTabArgs [ pos++ ] = NULL;
 				
 				// NORMALISATION PEAK
-				conv_to_convert (FALSE, NORMALISE_EXEC, "NORMALISE_EXEC Wav -> Peak");
-				filelc_get_command_line_remove ();
+				conv_to_convert (PtrTabArgs, FALSE, NORMALISE_EXEC, "NORMALISE_EXEC Wav -> Peak");
+				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 				
 				conv_copy_src_to_dest (Name, Audio->PathName_Dest_Wav);
 				g_unlink (Name);
@@ -1043,6 +1057,7 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			if (VarCdExtract.PassFileUnique >= VarCdExtract.NbrFileUnique) {
 				
 				GList	*list = NULL;
+				gchar	**PtrTabArgs = NULL;
 				
 				// conv_product_name_for_label (Audio->PathName_Dest_Wav);
 				switch (VarCdExtract.ChoiceFileCue) {
@@ -1052,28 +1067,29 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 				case 3 : Audio->Etat_Mpc  = ETAT_CONV_CD_WAITING;  break;
 			 	}
 								
-				pos = filelc_get_command_line_nice ();
-				conv.ArgConv [ pos++ ] = g_strdup ("sox");
+				PtrTabArgs = filelc_AllocTabArgs();
+				pos = 3;
+				PtrTabArgs [ pos++ ] = g_strdup ("sox");
 				list = g_list_first (VarCdExtract.ListFileFormatUnique);
 				while (list) {
 					if (NULL != (gchar *)list->data) {
-						conv.ArgConv [ pos++ ] = g_strdup ((gchar *)list->data);
+						PtrTabArgs [ pos++ ] = g_strdup ((gchar *)list->data);
 					}
 					list = g_list_next (list);
 				}
-				conv.ArgConv [ pos++ ] = g_strdup ("-t");
-				conv.ArgConv [ pos++ ] = g_strdup (".wav");
-				conv.ArgConv [ pos++ ] = g_strdup ("-S");
-				conv.ArgConv [ pos++ ] = g_strdup ("-r");
-				conv.ArgConv [ pos++ ] = g_strdup ("44100");
-				conv.ArgConv [ pos++ ] = g_strdup ("-c");
-				conv.ArgConv [ pos++ ] = g_strdup ("2");
-				conv.ArgConv [ pos++ ] = g_strdup ("-o");
-				conv.ArgConv [ pos++ ] = g_strdup (VarCdExtract.NameFileFormatUnique);
-				conv.ArgConv [ pos++ ] = NULL;
+				PtrTabArgs [ pos++ ] = g_strdup ("-t");
+				PtrTabArgs [ pos++ ] = g_strdup (".wav");
+				PtrTabArgs [ pos++ ] = g_strdup ("-S");
+				PtrTabArgs [ pos++ ] = g_strdup ("-r");
+				PtrTabArgs [ pos++ ] = g_strdup ("44100");
+				PtrTabArgs [ pos++ ] = g_strdup ("-c");
+				PtrTabArgs [ pos++ ] = g_strdup ("2");
+				PtrTabArgs [ pos++ ] = g_strdup ("-o");
+				PtrTabArgs [ pos++ ] = g_strdup (VarCdExtract.NameFileFormatUnique);
+				PtrTabArgs [ pos++ ] = NULL;
 				
-				conv_to_convert (FALSE, SOX_WAV_TO_WAV, "SOX_WAV_TO_WAV");
-				filelc_get_command_line_remove ();
+				conv_to_convert (PtrTabArgs, FALSE, SOX_WAV_TO_WAV, "SOX_WAV_TO_WAV");
+				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 				
 				PRINT("DEBUG FOR @DZEF");
 				if( TRUE == OptionsCommandLine.BoolVerboseMode )
@@ -1097,9 +1113,13 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 				g_print ("DEST   FLAC<%s>\n", Audio->PathName_Dest_Flac);
 			}
 			
-			cdaudioextract_restitue_arg_to_conv (Audio, NUM_FLAC);
-			conv_to_convert (Audio->ListConv[ NUM_FLAC ].WithCommandLineUser,  FLAC_WAV_TO_FLAC, "FLAC_WAV_TO_FLAC");
-			filelc_get_command_line_remove ();
+			PtrTabArgs = filelc_AllocTabArgs();
+			g_free( PtrTabArgs[ 0 ] );
+			g_free( PtrTabArgs[ 1 ] );
+			g_free( PtrTabArgs[ 2 ] );
+			cdaudioextract_restitue_arg_to_conv( PtrTabArgs, Audio, NUM_FLAC );
+			conv_to_convert (PtrTabArgs, Audio->ListConv[ NUM_FLAC ].WithCommandLineUser,  FLAC_WAV_TO_FLAC, "FLAC_WAV_TO_FLAC");
+			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 
 			Audio->EtatSelection_Flac = CD_ETAT_ATTENTE;
 
@@ -1120,9 +1140,13 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 				g_print ("DEST   APE <%s>\n", Audio->PathName_Dest_Ape);
 			}
 
-			cdaudioextract_restitue_arg_to_conv (Audio, NUM_APE);
-			conv_to_convert (Audio->ListConv[ NUM_APE ].WithCommandLineUser,  MAC_WAV_TO_APE, "MAC_WAV_TO_APE");
-			filelc_get_command_line_remove ();
+			PtrTabArgs = filelc_AllocTabArgs();
+			g_free( PtrTabArgs[ 0 ] );
+			g_free( PtrTabArgs[ 1 ] );
+			g_free( PtrTabArgs[ 2 ] );
+			cdaudioextract_restitue_arg_to_conv (PtrTabArgs, Audio, NUM_APE);
+			conv_to_convert (PtrTabArgs, Audio->ListConv[ NUM_APE ].WithCommandLineUser,  MAC_WAV_TO_APE, "MAC_WAV_TO_APE");
+			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 
 			Audio->EtatSelection_Ape = CD_ETAT_ATTENTE;
 
@@ -1148,9 +1172,13 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			
 			Audio->EtatBoolWavpack = TRUE;
 			
-			cdaudioextract_restitue_arg_to_conv (Audio, NUM_WAVPACK);
-			conv_to_convert (Audio->ListConv[ NUM_WAVPACK ].WithCommandLineUser,  WAVPACK_WAV_TO_WAVPACK, "WAVPACK_WAV_TO_WAVPACK");
-			filelc_get_command_line_remove ();
+			PtrTabArgs = filelc_AllocTabArgs();
+			g_free( PtrTabArgs[ 0 ] );
+			g_free( PtrTabArgs[ 1 ] );
+			g_free( PtrTabArgs[ 2 ] );
+			cdaudioextract_restitue_arg_to_conv (PtrTabArgs, Audio, NUM_WAVPACK);
+			conv_to_convert (PtrTabArgs, Audio->ListConv[ NUM_WAVPACK ].WithCommandLineUser,  WAVPACK_WAV_TO_WAVPACK, "WAVPACK_WAV_TO_WAVPACK");
+			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 			
 			Audio->EtatSelection_WavPack = CD_ETAT_ATTENTE;
 
@@ -1186,9 +1214,13 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 				g_print ("DEST   OGG <%s>\n", Audio->PathName_Dest_Ogg);
 			}
 
-			cdaudioextract_restitue_arg_to_conv (Audio, NUM_OGG);
-			conv_to_convert (Audio->ListConv[ NUM_OGG ].WithCommandLineUser, OGGENC_WAV_TO_OGG, "OGGENC_WAV_TO_OGG");
-			filelc_get_command_line_remove ();
+			PtrTabArgs = filelc_AllocTabArgs();
+			g_free( PtrTabArgs[ 0 ] );
+			g_free( PtrTabArgs[ 1 ] );
+			g_free( PtrTabArgs[ 2 ] );
+			cdaudioextract_restitue_arg_to_conv (PtrTabArgs, Audio, NUM_OGG);
+			conv_to_convert( PtrTabArgs, Audio->ListConv[ NUM_OGG ].WithCommandLineUser, OGGENC_WAV_TO_OGG, "OGGENC_WAV_TO_OGG");
+			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 			
 			Audio->EtatSelection_Ogg = CD_ETAT_ATTENTE;
 
@@ -1209,9 +1241,13 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 				g_print ("DEST   M4A <%s>\n", Audio->PathName_Dest_M4a);
 			}
 
-			cdaudioextract_restitue_arg_to_conv (Audio, NUM_M4A);
-			conv_to_convert (Audio->ListConv[ NUM_M4A ].WithCommandLineUser, FAAC_WAV_TO_M4A, "FAAC_WAV_TO_M4A");
-			filelc_get_command_line_remove ();
+			PtrTabArgs = filelc_AllocTabArgs();
+			g_free( PtrTabArgs[ 0 ] );
+			g_free( PtrTabArgs[ 1 ] );
+			g_free( PtrTabArgs[ 2 ] );
+			cdaudioextract_restitue_arg_to_conv (PtrTabArgs, Audio, NUM_M4A);
+			conv_to_convert( PtrTabArgs, Audio->ListConv[ NUM_M4A ].WithCommandLineUser, FAAC_WAV_TO_M4A, "FAAC_WAV_TO_M4A");
+			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 
 			Audio->EtatSelection_M4a = CD_ETAT_ATTENTE;
 
@@ -1232,9 +1268,13 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 				g_print ("DEST   AAC <%s>\n", Audio->PathName_Dest_Aac);
 			}
 
-			cdaudioextract_restitue_arg_to_conv (Audio, NUM_AAC);
-			conv_to_convert (Audio->ListConv[ NUM_AAC ].WithCommandLineUser, AACPLUSENC_WAV_TO_AAC, "AACPLUSENC_WAV_TO_AAC");
-			filelc_get_command_line_remove ();
+			PtrTabArgs = filelc_AllocTabArgs();
+			g_free( PtrTabArgs[ 0 ] );
+			g_free( PtrTabArgs[ 1 ] );
+			g_free( PtrTabArgs[ 2 ] );
+			cdaudioextract_restitue_arg_to_conv (PtrTabArgs, Audio, NUM_AAC);
+			conv_to_convert( PtrTabArgs, Audio->ListConv[ NUM_AAC ].WithCommandLineUser, AACPLUSENC_WAV_TO_AAC, "AACPLUSENC_WAV_TO_AAC");
+			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 
 			Audio->EtatSelection_Aac = CD_ETAT_ATTENTE;
 
@@ -1257,9 +1297,13 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 				g_print ("DEST   MPC <%s>\n", Audio->PathName_Dest_Mpc);
 			}
 
-			cdaudioextract_restitue_arg_to_conv (Audio, NUM_MPC);
-			conv_to_convert (Audio->ListConv[ NUM_MPC ].WithCommandLineUser, MPPENC_WAV_TO_MPC, "MPPENC_WAV_TO_MPC");
-			filelc_get_command_line_remove ();
+			PtrTabArgs = filelc_AllocTabArgs();
+			g_free( PtrTabArgs[ 0 ] );
+			g_free( PtrTabArgs[ 1 ] );
+			g_free( PtrTabArgs[ 2 ] );
+			cdaudioextract_restitue_arg_to_conv (PtrTabArgs, Audio, NUM_MPC);
+			conv_to_convert( PtrTabArgs, Audio->ListConv[ NUM_MPC ].WithCommandLineUser, MPPENC_WAV_TO_MPC, "MPPENC_WAV_TO_MPC");
+			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 
 			Audio->EtatSelection_Mpc = CD_ETAT_ATTENTE;
 
@@ -1280,9 +1324,13 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 				g_print ("DEST   MP3 <%s>\n", Audio->PathName_Dest_Mp3);
 			}
 
-			cdaudioextract_restitue_arg_to_conv (Audio, NUM_MP3);
-			conv_to_convert (Audio->ListConv[ NUM_MP3 ].WithCommandLineUser, LAME_WAV_TO_MP3, "LAME_WAV_TO_MP3");
-			filelc_get_command_line_remove ();
+			PtrTabArgs = filelc_AllocTabArgs();
+			g_free( PtrTabArgs[ 0 ] );
+			g_free( PtrTabArgs[ 1 ] );
+			g_free( PtrTabArgs[ 2 ] );
+			cdaudioextract_restitue_arg_to_conv (PtrTabArgs, Audio, NUM_MP3);
+			conv_to_convert( PtrTabArgs, Audio->ListConv[ NUM_MP3 ].WithCommandLineUser, LAME_WAV_TO_MP3, "LAME_WAV_TO_MP3");
+			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 			
 			Audio->EtatSelection_Mp3 = CD_ETAT_ATTENTE;
 
