@@ -67,6 +67,7 @@ extern int kill (pid_t pid, int sig);
 
 CONV conv;
 
+
 /*
 *---------------------------------------------------------------------------
 * STOP THREAD AND TIMEOUT
@@ -277,7 +278,6 @@ void conv_reset_struct (void *p_func)
 	conv.Bool_MAJ_select = FALSE;
 	
 	for (i = 0; i < MAX_ARG_CONV; i++) {
-		conv.ArgConv [ i ]    = NULL;
 		conv.ArgExtract [ i ] = NULL;
 	}
 }
@@ -498,46 +498,70 @@ void conv_with_sox_ARGS (gchar **args)
 	conv.code_fork_conv = -1;
 	conv.conversion_percent = 0.0;
 }
-void conv_with_sox_get_param (gchar *filesrc, gchar *filedest, gchar *frequence, gchar *voie, gchar *bits)
+gchar **conv_with_sox_get_param( gchar *filesrc, gchar *filedest, gchar *frequence, gchar *voie, gchar *bits )
 {
 	gint	pos;
+	gchar	**PtrTabArgs = NULL;
 	
-	pos = filelc_get_command_line_nice ();
-	conv.ArgConv [ pos++ ] = g_strdup ("sox");
-	conv.ArgConv [ pos++ ] = g_strdup ("-t");
-	conv.ArgConv [ pos++ ] = g_strdup (".wav");
-	conv.ArgConv [ pos++ ] = g_strdup (filesrc);
-	conv.ArgConv [ pos++ ] = g_strdup ("-S");
-	conv.ArgConv [ pos++ ] = g_strdup ("-r");
-	conv.ArgConv [ pos++ ] = g_strdup (frequence);
-	conv.ArgConv [ pos++ ] = g_strdup ("-c");
-	conv.ArgConv [ pos++ ] = g_strdup (voie);
+	PtrTabArgs = filelc_AllocTabArgs();
+	pos = 3;
+	PtrTabArgs [ pos++ ] = g_strdup ("sox");
+	PtrTabArgs [ pos++ ] = g_strdup ("-t");
+	PtrTabArgs [ pos++ ] = g_strdup (".wav");
+	PtrTabArgs [ pos++ ] = g_strdup (filesrc);
+	PtrTabArgs [ pos++ ] = g_strdup ("-S");
+	PtrTabArgs [ pos++ ] = g_strdup ("-r");
+	PtrTabArgs [ pos++ ] = g_strdup (frequence);
+	PtrTabArgs [ pos++ ] = g_strdup ("-c");
+	PtrTabArgs [ pos++ ] = g_strdup (voie);
 	
 	switch (atoi (bits)) {
-		case 8 :  conv.ArgConv [ pos++ ] = g_strdup ("-1"); break;
-		case 16 : conv.ArgConv [ pos++ ] = g_strdup ("-2"); break;
-		case 24 : conv.ArgConv [ pos++ ] = g_strdup ("-3"); break;
-		case 32 : conv.ArgConv [ pos++ ] = g_strdup ("-4"); break;
-		case 64 : conv.ArgConv [ pos++ ] = g_strdup ("-8"); break;
-		default : conv.ArgConv [ pos++ ] = g_strdup ("-2"); break;
+		case 8 :  PtrTabArgs [ pos++ ] = g_strdup ("-1"); break;
+		case 16 : PtrTabArgs [ pos++ ] = g_strdup ("-2"); break;
+		case 24 : PtrTabArgs [ pos++ ] = g_strdup ("-3"); break;
+		case 32 : PtrTabArgs [ pos++ ] = g_strdup ("-4"); break;
+		case 64 : PtrTabArgs [ pos++ ] = g_strdup ("-8"); break;
+		default : PtrTabArgs [ pos++ ] = g_strdup ("-2"); break;
 	}
-	conv.ArgConv [ pos++ ] = g_strdup ("-o");
-	conv.ArgConv [ pos++ ] = g_strdup (filedest);
-	conv.ArgConv [ pos++ ] = NULL;
+	PtrTabArgs [ pos++ ] = g_strdup ("-o");
+	PtrTabArgs [ pos++ ] = g_strdup (filedest);
+	PtrTabArgs [ pos++ ] = NULL;
+	
+	return( (gchar **)PtrTabArgs );
 }
-void conv_with_sox_float_get_param (gchar *filesrc, gchar *filedest)
+gchar **conv_with_sox_float_get_param( gchar *filesrc, gchar *filedest )
 {
 	gint	pos;
+	gchar	**PtrTabArgs = NULL;
 	
-	pos = filelc_get_command_line_nice ();
-	conv.ArgConv [ pos++ ] = g_strdup ("sox");
-	conv.ArgConv [ pos++ ] = g_strdup (filesrc);
-	conv.ArgConv [ pos++ ] = g_strdup ("-t");
-	conv.ArgConv [ pos++ ] = g_strdup ("wavpcm");
-	conv.ArgConv [ pos++ ] = g_strdup ("-S");
-	conv.ArgConv [ pos++ ] = g_strdup ("-f");
-	conv.ArgConv [ pos++ ] = g_strdup ("-o");
-	conv.ArgConv [ pos++ ] = g_strdup (filedest);
+	PtrTabArgs = filelc_AllocTabArgs();
+	pos = 3;
+	PtrTabArgs [ pos++ ] = g_strdup ("sox");
+	PtrTabArgs [ pos++ ] = g_strdup (filesrc);
+	PtrTabArgs [ pos++ ] = g_strdup ("-t");
+	PtrTabArgs [ pos++ ] = g_strdup ("wavpcm");
+	PtrTabArgs [ pos++ ] = g_strdup ("-S");
+	PtrTabArgs [ pos++ ] = g_strdup ("-f");
+	PtrTabArgs [ pos++ ] = g_strdup ("-o");
+	PtrTabArgs [ pos++ ] = g_strdup (filedest);
+	PtrTabArgs [ pos++ ] = NULL;
+	
+	return( (gchar **)PtrTabArgs );
+}
+gchar **conv_lsdvd_read_get_param( gchar *p_PathDvd )
+{
+	gint	pos;
+	gchar	**PtrTabArgs = NULL;
+	
+	PtrTabArgs = filelc_AllocTabArgs();
+	pos = 3;
+	PtrTabArgs [ pos++ ] =  g_strdup( "lsdvd" );
+	PtrTabArgs [ pos++ ] =  g_strdup( p_PathDvd );
+	PtrTabArgs [ pos++ ] =  g_strdup( "-x" );
+	PtrTabArgs [ pos++ ] =  g_strdup( "2>&1" );
+	PtrTabArgs [ pos++ ] = NULL;
+	
+	return( (gchar **)PtrTabArgs );
 }
 // FLAC
 // 
@@ -1934,12 +1958,12 @@ void conv_with_a52dec_ARGS (gchar **args)
 
 // CALL CONV
 // 
-gboolean conv_to_convert (gboolean WithParameter, TYPE_CONV type_conv, gchar *info)
+gboolean conv_to_convert( gchar **p_TabArgs, gboolean WithParameter, TYPE_CONV type_conv, gchar *info )
 {
 	gint             pos = 0;
 	gboolean	 RetBool = TRUE;
 		
-	PRINT_FUNC_LF();
+	// PRINT_FUNC_LF();
 	
 	if (NORMALISE_CALCUL == type_conv || NORMALISE_APPLIQUE == type_conv || NORMALISE_EXEC == type_conv || NORMALISE_GET_LEVEL == type_conv) {
 		conv.BoolIsNormalise = TRUE;
@@ -1950,9 +1974,6 @@ gboolean conv_to_convert (gboolean WithParameter, TYPE_CONV type_conv, gchar *in
 	else if (MPLAYER_AUDIO_TO_WAV == type_conv) {
 		conv.BoolIsExtract = TRUE;
 	}
-	else if (A52DEC_AC3_TO_WAV == type_conv) {
-		conv.BoolIsa52dec = TRUE;
-	}
 	else {
 		conv.BoolIsConvert = TRUE;
 	}
@@ -1967,48 +1988,48 @@ gboolean conv_to_convert (gboolean WithParameter, TYPE_CONV type_conv, gchar *in
 		g_print ("!  %s\n", info);
 		g_print ("!-----------------------------------------------------------!\n");
 		g_print ("!  ");
-		for (pos = 0; conv.ArgConv[ pos ] != NULL; pos ++) {
-			g_print ("%s ", conv.ArgConv[ pos ]);
+		for (pos = 0; p_TabArgs[ pos ] != NULL; pos ++) {
+			g_print ("%s ", p_TabArgs[ pos ]);
 		}
 		g_print ("\n!-----------------------------------------------------------!\n");
-		for (pos = 0; conv.ArgConv[ pos ] != NULL; pos ++) {
-			g_print ("ArgConv[ %02d ] = %s\n", pos, conv.ArgConv[ pos ]);
+		for (pos = 0; p_TabArgs[ pos ] != NULL; pos ++) {
+			g_print ("p_TabArgs[ %02d ] = %s\n", pos, p_TabArgs[ pos ]);
 		}
 		g_print ("\n");
 	}
-
+	
 	switch (type_conv) {
 	case NONE_CONV :
 		break;
 	case FLAC_FLAC_TO_WAV :
 	case FLAC_WAV_TO_FLAC :
-		RetBool = conv_with_flac_ARGS (conv.ArgConv);
+		RetBool = conv_with_flac_ARGS( p_TabArgs );
 		break;
 	case LAME_WAV_TO_MP3 :
 	case LAME_FLAC_TO_MP3 :
-		conv_with_lame_ARGS (conv.ArgConv);
+		conv_with_lame_ARGS( p_TabArgs );
 		break;
 	case OGGENC_WAV_TO_OGG :
 	case OGGENC_FLAC_TO_OGG :
-		conv_with_oggenc_ARGS (conv.ArgConv);
+		conv_with_oggenc_ARGS( p_TabArgs );
 		break;
 	case OGG123_OGG_TO_WAV :
-		conv_with_ogg123_ARGS (conv.ArgConv);
+		conv_with_ogg123_ARGS( p_TabArgs );
 		break;
 	case MPG321_MP3_TO_WAV :
-		conv_with_mpg321_ARGS (conv.ArgConv);
+		conv_with_mpg321_ARGS( p_TabArgs );
 		break;
 	case SOX_WAV_TO_WAV :
-		conv_with_sox_ARGS (conv.ArgConv);
+		conv_with_sox_ARGS( p_TabArgs );
 		break;
 	case SHORTEN_SHN_TO_WAV :
-		conv_with_shorten_ARGS (conv.ArgConv);
+		conv_with_shorten_ARGS( p_TabArgs );
 		break;
 	case FAAD_M4A_TO_WAV :
-		conv_with_faad_ARGS (conv.ArgConv);
+		conv_with_faad_ARGS( p_TabArgs );
 		break;
 	case FAAC_WAV_TO_M4A :
-		conv_with_faac_ARGS (conv.ArgConv);
+		conv_with_faac_ARGS( p_TabArgs );
 		break;
 	case MPLAYER_WMA_TO_WAV :
 	case MPLAYER_RM_TO_WAV :
@@ -2019,33 +2040,34 @@ gboolean conv_to_convert (gboolean WithParameter, TYPE_CONV type_conv, gchar *in
 	case MPLAYER_M4A_TO_WAV :
 	case MPLAYER_OGG_TO_WAV :
 	case MPLAYER_MP3_TO_WAV :
-		RetBool = conv_with_mplayer_ARGS (conv.ArgConv, type_conv);
+	case MPLAYER_MPC_TO_WAV :
+		RetBool = conv_with_mplayer_ARGS( p_TabArgs, type_conv );
 		break;
 	case COPY_FILE :
 		break;
 	case NORMALISE_CALCUL :
 	case NORMALISE_APPLIQUE :
 	case NORMALISE_EXEC :
-		conv_with_normalise_ARGS (conv.ArgConv);
+		conv_with_normalise_ARGS( p_TabArgs );
 		break;
 	case NORMALISE_GET_LEVEL:
-		conv_with_normalise_get_PEAK_RMS_GROUP_ARGS (conv.ArgConv);
+		conv_with_normalise_get_PEAK_RMS_GROUP_ARGS( p_TabArgs );
 		break;
 	case MPPDEC_MPC_TO_WAV :
-		conv_with_mppdec_ARGS (conv.ArgConv);
+		conv_with_mppdec_ARGS( p_TabArgs );
 		break;
 	case MPPENC_WAV_TO_MPC :
-		conv_with_mppenc_ARGS (conv.ArgConv);
+		conv_with_mppenc_ARGS( p_TabArgs );
 		break;
 	case MAC_APE_TO_WAV :
 	case MAC_WAV_TO_APE :
-		conv_with_mac_ARGS (conv.ArgConv);
+		conv_with_mac_ARGS( p_TabArgs );
 		break;
 	case WAVPACK_WAV_TO_WAVPACK :
-		conv_with_wavpack_ARGS (conv.ArgConv);
+		conv_with_wavpack_ARGS( p_TabArgs );
 		break;
 	case WVUNPACK_WAVPACK_TO_WAV :
-		conv_with_wvunpack_ARGS (conv.ArgConv);
+		conv_with_wvunpack_ARGS( p_TabArgs );
 		break;
 	
 	case CDPARANOIA_CD_TO_WAV :
@@ -2055,32 +2077,32 @@ gboolean conv_to_convert (gboolean WithParameter, TYPE_CONV type_conv, gchar *in
 		break;
 	
 	case REPLAYGAIN :
-		conv_with_replaygain_ARGS (conv.ArgConv);
+		conv_with_replaygain_ARGS( p_TabArgs );
 		break;
 	case LSDVD :
-		conv_with_lsdvd_ARGS (conv.ArgConv);
+		conv_with_lsdvd_ARGS( p_TabArgs );
 		break;
 	case SPLIT :
-		conv_with_split_ARGS (conv.ArgConv);
+		conv_with_split_ARGS( p_TabArgs );
 		break;
 	case CDDB_TOOL :
-		conv_with_cddb_tool_ARGS (conv.ArgConv);
+		conv_with_cddb_tool_ARGS( p_TabArgs );
 		break;
 	
 	case ICEDAX :
-		RetBool = conv_with_icedax_tool_ARGS (conv.ArgConv);
+		RetBool = conv_with_icedax_tool_ARGS( p_TabArgs );
 		break;
 
 	case AACPLUSENC_WAV_TO_AAC :
-		conv_with_aacplusenc_ARGS (conv.ArgConv);
+		conv_with_aacplusenc_ARGS( p_TabArgs );
 		break;
 		
 	case WAVSPLIT_EXTRACT :
-		conv_with_wavsplit_ARGS (conv.ArgConv);
+		conv_with_wavsplit_ARGS( p_TabArgs );
 		break;
 	
 	case A52DEC_AC3_TO_WAV :
-		conv_with_a52dec_ARGS (conv.ArgConv);
+		conv_with_a52dec_ARGS( p_TabArgs );
 		break;
 	}
 	
@@ -2090,7 +2112,6 @@ gboolean conv_to_convert (gboolean WithParameter, TYPE_CONV type_conv, gchar *in
 	conv.BoolIsNormalise  = FALSE;
 	conv.BoolIsReplaygain = FALSE;
 	if (MPLAYER_AUDIO_TO_WAV == type_conv) 	conv.BoolIsExtract = FALSE;
-	conv.BoolIsa52dec = FALSE;
 
 	return (RetBool);
 }
