@@ -57,6 +57,7 @@ typedef enum {						// Les types de conversions possibles
 	MPLAYER_M4A_TO_WAV,				// 
 	MPLAYER_OGG_TO_WAV,				// 
 	MPLAYER_MP3_TO_WAV,				// 
+	MPLAYER_MPC_TO_WAV,				// 
 	MPLAYER_RM_TO_WAV,				// 
 	MPLAYER_DTS_TO_WAV,				// 
 	MPLAYER_AIFF_TO_WAV,				// 
@@ -139,7 +140,6 @@ typedef struct {
 	
 	gboolean	Bool_MAJ_select;		// TRUE
 
-	gchar		*ArgConv [ MAX_ARG_CONV + 20 ];		// 
 	gchar		*ArgExtract [ MAX_ARG_CONV + 20 ];	// 
 	
 	double		value_PEAK_RMS_GROUP_ARGS;	// 
@@ -150,15 +150,18 @@ typedef struct {
 
 extern CONV conv;
 
-void      conv_inc_rip_completed (void);
-void      conv_inc_encode_completed (void);
-void      conv_stop_conversion (void);
-void	  conv_reset_struct (void *p_func);
-gboolean  conv_to_convert (gboolean WithParameter, TYPE_CONV type_conv, gchar *info);
-gboolean  conv_exec_extract (gboolean WithParameter, TYPE_CONV type_conv, gchar *info);
-gboolean  conv_copy_src_to_dest (gchar *filesrc, gchar *filedest);
-void	  conv_with_sox_get_param (gchar *filesrc, gchar *filedest, gchar *frequence, gchar *voie, gchar *bits);
-void	  conv_with_sox_float_get_param (gchar *filesrc, gchar *filedest);
+void		conv_inc_rip_completed (void);
+void		conv_inc_encode_completed (void);
+void		conv_stop_conversion (void);
+void		conv_reset_struct (void *p_func);
+
+gboolean	conv_to_convert( gchar **p_TabArgs, gboolean WithParameter, TYPE_CONV type_conv, gchar *info );
+
+gboolean  	conv_exec_extract (gboolean WithParameter, TYPE_CONV type_conv, gchar *info);
+gboolean  	conv_copy_src_to_dest (gchar *filesrc, gchar *filedest);
+gchar 		**conv_with_sox_get_param (gchar *filesrc, gchar *filedest, gchar *frequence, gchar *voie, gchar *bits);
+gchar		**conv_with_sox_float_get_param (gchar *filesrc, gchar *filedest);
+gchar		**conv_lsdvd_read_get_param( gchar *p_PathDvd );
 
 #endif
 
