@@ -70,8 +70,9 @@ typedef struct {
 } INFO_AAC;
 
 typedef struct {
-	gchar			*time;					//  Temps d'ecoute
-	guint			 SecTime;				//  Temps d'ecoute en secondes
+	gboolean		 BoolBwf;				// 'fmt ', 'bext', 'qlty', 'levl', 'link','axml'
+	gchar			*time;					// Temps d'ecoute
+	guint			 SecTime;				// Temps d'ecoute en secondes
 	gchar			*hertz;					// Taux d'échantillonnage en hertz( qualité du son)
 	gchar			*voie;					// 1, 2, 4, 6
 	gchar			*bits;					// 8, 16, ,24, 32 ou 64
@@ -385,7 +386,8 @@ typedef struct {
 	ETAT_CONV_FILE		 Etat_Mpc;				// 
 	ETAT_CONV_FILE		 Etat_Ape;				// 
 	ETAT_CONV_FILE		 Etat_wavpack;				// 
-	gboolean		 BoolNewString;
+	gboolean		 BoolNewString;				// 
+		
 } CONV_FIC;
 
 typedef enum {
@@ -437,6 +439,8 @@ typedef struct {
 	gint			Ogg_Managed;				// 
 	gint			Ogg_Downmix;				// 
 	gboolean		BoolChanged;				// 
+	
+	gboolean		BoolConvertActivate;			// 
 } DETAIL;
 
 extern GList *entetefile;						// pointeur sur DETAIL
@@ -711,9 +715,14 @@ typedef struct {
 	gchar		*PtrStrBitrate;
 } PARAM_FILELC;
 
-gint		filelc_get_command_line_remove( void );
-gint		filelc_get_command_line_nice( void );
-void		filelc_get_command_line( PARAM_FILELC *param_filelc );
+// 
+// Allocate Tab Args
+// 
+gchar		**filelc_AllocTabArgs( void );
+gchar		**filelc_RevoveTab( gchar **p_PtrTabArgs );
+// gint		filelc_get_command_line_remove( void );
+// gint		filelc_get_command_line_nice( void );
+gchar		**filelc_get_command_line( PARAM_FILELC *param_filelc );
 void		filelc_get_command_line_extract( PARAM_FILELC *param_filelc );
 GList		*filelc_remove_glist( GList *New );
 void		filelc_get_command_line_extract_elem( gint Elem, gchar *Dev, gchar *Dest );
