@@ -53,33 +53,37 @@
 
 
 // 
+// Allocate Tab Args
 // 
-gint filelc_get_command_line_remove (void)
+gchar **filelc_AllocTabArgs( void )
 {
-	gint	pos = 0;
+	gchar	**PtrTab = (gchar **)g_malloc0( sizeof(gchar **) * 50 );
+
+	PtrTab [ 0 ] = g_strdup( "nice" );
+	PtrTab [ 1 ] = g_strdup( "-n" );
+	PtrTab [ 2 ] = g_strdup_printf( "%d", Config.Nice );
+
+	return( (gchar **)PtrTab );
+}
+// 
+// Remove Tab Args
+// 
+gchar **filelc_RevoveTab( gchar **p_PtrTabArgs )
+{
+	gint	i;
 	
-	for (pos = 0; conv.ArgConv [ pos ] != NULL; pos ++) {
-		g_free (conv.ArgConv [ pos ]);
-		conv.ArgConv [ pos ] = NULL;
+	for( i = 0; p_PtrTabArgs[ i ] != NULL; i ++ ) {
+		g_free( p_PtrTabArgs[ i ] );
+		p_PtrTabArgs[ i ] = NULL;
 	}
-	return (0);
+	g_free( p_PtrTabArgs );
+	p_PtrTabArgs = NULL;
+	
+	return( (gchar **)NULL );
 }
 // 
 // 
-gint filelc_get_command_line_nice (void)
-{
-	gint	pos = filelc_get_command_line_remove ();
-	
-	conv.ArgConv [ pos++ ] = g_strdup ("nice");
-	conv.ArgConv [ pos++ ] = g_strdup ("-n");
-	conv.ArgConv [ pos++ ] = g_strdup_printf ("%d", Config.Nice);
-	
-	// RETOURNE LA PROCHANE POSITION DE pos
-	return (3);
-}
-// 
-// 
-gint filelc_analyse_line (gchar *entry, gint *pos, TAGS *tags)
+gint filelc_analyse_line( gchar **p_PtrTabArgs, gchar *entry, gint *pos, TAGS *tags )
 {
 	gchar     **Larrbuf = NULL;
 	gchar      *ptr = entry;
@@ -91,8 +95,7 @@ gint filelc_analyse_line (gchar *entry, gint *pos, TAGS *tags)
 	while (ptr && *ptr) {
 		if (*ptr == '\"') {
 			if (bool_open == TRUE) {
-				conv.ArgConv [ (*pos) ++ ] = g_strdup (gstr->str);
-				
+				p_PtrTabArgs[(*pos) ++ ] = g_strdup (gstr->str);
 				g_string_free (gstr, TRUE);
 				gstr = NULL;
 				ptr ++;
@@ -114,7 +117,7 @@ gint filelc_analyse_line (gchar *entry, gint *pos, TAGS *tags)
 
 		if (*ptr == ' ') {
 			if (gstr != NULL && *gstr->str) {
-				conv.ArgConv [ (*pos) ++ ] = g_strdup (gstr->str);
+				p_PtrTabArgs[(*pos) ++ ] = g_strdup (gstr->str);
 				
 				g_string_free (gstr, TRUE);
 				gstr = NULL;
@@ -137,7 +140,7 @@ gint filelc_analyse_line (gchar *entry, gint *pos, TAGS *tags)
 
 			/* OGGENC_WAV_TO_OGG | OGGENC_FLAC_TO_OGG */
 			if (*ptr == 'b' && (*(ptr+1) == ' ' || *(ptr+1) == '\0')) {
-				conv.ArgConv [ (*pos) ++ ] = g_strdup_printf ("%s", optionsOggenc_get_val_bitrate_oggenc ());
+				p_PtrTabArgs[(*pos) ++ ] = g_strdup_printf ("%s", optionsOggenc_get_val_bitrate_oggenc ());
 				
 				ptr ++;
 			}
@@ -145,7 +148,7 @@ gint filelc_analyse_line (gchar *entry, gint *pos, TAGS *tags)
 			else if (*ptr == 'b' && *(ptr+1) == 'l' && (*(ptr+2) == ' ' || *(ptr+2) == '\0')) {
 				Larrbuf = g_strsplit (optionsLame_get_str_val_bitrate_abr_vbr_lame (), " ", 0);
 				for (i=0; Larrbuf[i]; i++) {
-					conv.ArgConv [ (*pos) ++ ] = g_strdup (Larrbuf[i]);
+					p_PtrTabArgs[(*pos) ++ ] = g_strdup (Larrbuf[i]);
 					
 				}
 				g_strfreev(Larrbuf);
@@ -186,109 +189,121 @@ gint filelc_analyse_line (gchar *entry, gint *pos, TAGS *tags)
 		}
 	}
 	if (gstr != NULL && *gstr->str) {
-		conv.ArgConv [ (*pos) ++ ] = g_strdup (gstr->str);
+		p_PtrTabArgs[(*pos) ++ ] = g_strdup (gstr->str);
 		
 		g_string_free (gstr, TRUE);
 		gstr = NULL;
 	}
-	return (*pos);
+	return( *pos );
 }
-void filelc_analyse_command_line (PARAM_FILELC *param_filelc, gchar *entry)
+gchar **filelc_analyse_command_line( PARAM_FILELC *param_filelc, gchar *entry )
 {
 	gint	pos = 0;
+	gchar	**PtrTabArgs = NULL;
 	
 	if (param_filelc->type_conv == LAME_WAV_TO_MP3) {
 		
-		pos = filelc_get_command_line_nice ();
-		conv.ArgConv [ pos++ ] = g_strdup ("lame");
-		pos = filelc_analyse_line (entry, &pos, param_filelc->tags);
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filesrc);
-		conv.ArgConv [ pos++ ] = g_strdup ("-o");
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filedest);
-		conv.ArgConv [ pos++ ] = NULL;
+		PtrTabArgs = filelc_AllocTabArgs();
+		pos = 3; 
+		PtrTabArgs[ pos++ ] = g_strdup ("lame");
+		pos = filelc_analyse_line( PtrTabArgs, entry, &pos, param_filelc->tags );
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filesrc);
+		PtrTabArgs[ pos++ ] = g_strdup ("-o");
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filedest);
+		PtrTabArgs[ pos++ ] = NULL;
 	}
 	else if (param_filelc->type_conv == OGGENC_WAV_TO_OGG || param_filelc->type_conv == OGGENC_FLAC_TO_OGG) {
 		
-		pos = filelc_get_command_line_nice ();
-		conv.ArgConv [ pos++ ] = g_strdup ("oggenc");
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filesrc);
-		pos = filelc_analyse_line (entry, &pos, param_filelc->tags);
-		conv.ArgConv [ pos++ ] = g_strdup ("-o");
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filedest);
-		conv.ArgConv [ pos++ ] = NULL;
+		PtrTabArgs = filelc_AllocTabArgs();
+		pos = 3;
+		PtrTabArgs[ pos++ ] = g_strdup ("oggenc");
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filesrc);
+		pos = filelc_analyse_line (PtrTabArgs, entry, &pos, param_filelc->tags);
+		PtrTabArgs[ pos++ ] = g_strdup ("-o");
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filedest);
+		PtrTabArgs[ pos++ ] = NULL;
 	}
 	else if (param_filelc->type_conv == FLAC_WAV_TO_FLAC) {
 		
-		pos = filelc_get_command_line_nice ();
-		conv.ArgConv [ pos++ ] = g_strdup ("flac");
-		pos = filelc_analyse_line (entry, &pos, param_filelc->tags);
-		conv.ArgConv [ pos++ ] = g_strdup ("-f");
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filesrc);
-		conv.ArgConv [ pos++ ] = g_strdup ("-o");
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filedest);
-		conv.ArgConv [ pos++ ] = NULL;
+		PtrTabArgs = filelc_AllocTabArgs();
+		pos = 3;
+		PtrTabArgs[ pos++ ] = g_strdup ("flac");
+		pos = filelc_analyse_line (PtrTabArgs, entry, &pos, param_filelc->tags);
+		PtrTabArgs[ pos++ ] = g_strdup ("-f");
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filesrc);
+		PtrTabArgs[ pos++ ] = g_strdup ("-o");
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filedest);
+		PtrTabArgs[ pos++ ] = NULL;
 	}
 	else if (param_filelc->type_conv == FAAC_WAV_TO_M4A) {
 		
-		pos = filelc_get_command_line_nice ();
-		conv.ArgConv [ pos++ ] = g_strdup ("faac");
-		pos = filelc_analyse_line (entry, &pos, param_filelc->tags);
-		conv.ArgConv [ pos++ ] = g_strdup ("-o");
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filedest);
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filesrc);
-		conv.ArgConv [ pos++ ] = NULL;
+		PtrTabArgs = filelc_AllocTabArgs();
+		pos = 3;
+		PtrTabArgs[ pos++ ] = g_strdup ("faac");
+		pos = filelc_analyse_line (PtrTabArgs, entry, &pos, param_filelc->tags);
+		PtrTabArgs[ pos++ ] = g_strdup ("-o");
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filedest);
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filesrc);
+		PtrTabArgs[ pos++ ] = NULL;
 	}
 	else if (param_filelc->type_conv == MPPENC_WAV_TO_MPC) {
 		
-		pos = filelc_get_command_line_nice ();
-		conv.ArgConv [ pos++ ] = g_strdup (prginit_get_name (NMR_musepack_tools_mppenc));
-		pos = filelc_analyse_line (entry, &pos, param_filelc->tags);
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filesrc);
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filedest);
-		conv.ArgConv [ pos++ ] = NULL;
+		PtrTabArgs = filelc_AllocTabArgs();
+		pos = 3;
+		PtrTabArgs[ pos++ ] = g_strdup (prginit_get_name (NMR_musepack_tools_mppenc));
+		pos = filelc_analyse_line (PtrTabArgs, entry, &pos, param_filelc->tags);
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filesrc);
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filedest);
+		PtrTabArgs[ pos++ ] = NULL;
 	}
 	else if (param_filelc->type_conv == MAC_WAV_TO_APE || param_filelc->type_conv == MAC_APE_TO_WAV) {
 		
-		pos = filelc_get_command_line_nice ();
-		conv.ArgConv [ pos++ ] = g_strdup (prginit_get_name (NMR_mac));
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filesrc);
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filedest);
-		conv.ArgConv [ pos++ ] = NULL;
+		PtrTabArgs = filelc_AllocTabArgs();
+		pos = 3;
+		PtrTabArgs[ pos++ ] = g_strdup (prginit_get_name (NMR_mac));
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filesrc);
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filedest);
+		PtrTabArgs[ pos++ ] = NULL;
 	}
 	else if (param_filelc->type_conv == WAVPACK_WAV_TO_WAVPACK) {
 		
-		pos = filelc_get_command_line_nice ();
-		conv.ArgConv [ pos++ ] = g_strdup ("wavpack");
-		pos = filelc_analyse_line (entry, &pos, param_filelc->tags);
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filesrc);
-		conv.ArgConv [ pos++ ] = g_strdup ("-o");
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filedest);
-		conv.ArgConv [ pos++ ] = NULL;
+		PtrTabArgs = filelc_AllocTabArgs();
+		pos = 3;
+		PtrTabArgs[ pos++ ] = g_strdup ("wavpack");
+		pos = filelc_analyse_line (PtrTabArgs, entry, &pos, param_filelc->tags);
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filesrc);
+		PtrTabArgs[ pos++ ] = g_strdup ("-o");
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filedest);
+		PtrTabArgs[ pos++ ] = NULL;
 	}
 	else if (param_filelc->type_conv == CDPARANOIA_CD_TO_WAV) {
 		
-		pos = filelc_get_command_line_nice ();
-		conv.ArgConv [ pos++ ] = g_strdup ("cdparanoia");
-		conv.ArgConv [ pos++ ] = g_strdup ("-e");
-		conv.ArgConv [ pos++ ] = g_strdup ("-d");
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->cdrom);
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->num_track);
-		pos = filelc_analyse_line (entry, &pos, param_filelc->tags);
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filedest);
-		conv.ArgConv [ pos++ ] = NULL;
+		PtrTabArgs = filelc_AllocTabArgs();
+		pos = 3;
+		PtrTabArgs[ pos++ ] = g_strdup ("cdparanoia");	
+		PtrTabArgs[ pos++ ] = g_strdup ("-e");
+		PtrTabArgs[ pos++ ] = g_strdup ("-d");
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->cdrom);
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->num_track);
+		pos = filelc_analyse_line (PtrTabArgs, entry, &pos, param_filelc->tags);
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filedest);
+		PtrTabArgs[ pos++ ] = NULL;
 	}
 	else if (param_filelc->type_conv == CDDA2WAV_CD_TO_WAV) {
 		
-		pos = filelc_get_command_line_nice ();
-		conv.ArgConv [ pos++ ] = g_strdup ("cdda2wav");
-		conv.ArgConv [ pos++ ] = g_strdup ("-D");
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->cdrom);
-		conv.ArgConv [ pos++ ] = g_strdup ("-O");
-		conv.ArgConv [ pos++ ] = g_strdup ("wav");
-		conv.ArgConv [ pos++ ] = g_strdup ("-t");
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->num_track);
-		conv.ArgConv [ pos++ ] = NULL;
+		PtrTabArgs = filelc_AllocTabArgs();
+		pos = 3;
+		PtrTabArgs[ pos++ ] = g_strdup ("cdda2wav");
+		PtrTabArgs[ pos++ ] = g_strdup ("-D");
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->cdrom);
+		PtrTabArgs[ pos++ ] = g_strdup ("-O");
+		PtrTabArgs[ pos++ ] = g_strdup ("wav");
+		PtrTabArgs[ pos++ ] = g_strdup ("-t");
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->num_track);
+		PtrTabArgs[ pos++ ] = NULL;
 	}
+	
+	return( (gchar **)PtrTabArgs );
 }
 // 
 // 
@@ -320,35 +335,39 @@ gboolean filelc_bool_add_line_command (TYPE_CONV p_type_conv, gchar **entry)
 }
 // 
 // 
-void filelc_get_command_line (PARAM_FILELC *param_filelc)
+gchar **filelc_get_command_line( PARAM_FILELC *param_filelc )
 {
 	gint	pos = 0;
 	gchar	*entry = NULL;
+	gchar	**PtrTabArgs = NULL;
 	
 	// OPTIONS LIGNE DE SAISIE UTILISATEUR
 	if (TRUE == param_filelc->With_CommandLineUser &&
 	    TRUE == filelc_bool_add_line_command (param_filelc->type_conv, &entry)) {
 		
-		filelc_analyse_command_line (param_filelc, entry);
-		return;
+		PtrTabArgs = filelc_analyse_command_line( param_filelc, entry );
+		return( (gchar **)PtrTabArgs );
 	}
+	
 	param_filelc->With_CommandLineUser = FALSE;
 	
+	PtrTabArgs = filelc_AllocTabArgs();
+	
 	if (param_filelc->type_conv == LAME_WAV_TO_MP3) {
 		
 		gchar	**Larrbuf = NULL;
 		gint	  i;
 		
-		pos = filelc_get_command_line_nice ();
-		conv.ArgConv [ pos++ ] = g_strdup ("lame");
-		conv.ArgConv [ pos++ ] = g_strdup ("-h");
-		conv.ArgConv [ pos++ ] = g_strdup ("--nohist");
-		conv.ArgConv [ pos++ ] = g_strdup ("--noreplaygain");
+		pos = 3;
+		PtrTabArgs [ pos++ ] = g_strdup ("lame");
+		PtrTabArgs [ pos++ ] = g_strdup ("-h");
+		PtrTabArgs [ pos++ ] = g_strdup ("--nohist");
+		PtrTabArgs [ pos++ ] = g_strdup ("--noreplaygain");
 		
 		if (param_filelc->PtrStrBitrate != NULL) {
 			Larrbuf = g_strsplit (param_filelc->PtrStrBitrate, " ", 0);
 			for (i=0; Larrbuf[i]; i++) {
-				conv.ArgConv [ pos++ ] = g_strdup (Larrbuf[i]);
+				PtrTabArgs [ pos++ ] = g_strdup (Larrbuf[i]);
 			}
 			g_strfreev(Larrbuf);
 			g_free (param_filelc->PtrStrBitrate);
@@ -358,27 +377,27 @@ void filelc_get_command_line (PARAM_FILELC *param_filelc)
 		
 		if (Config.BoolArtistTag || Config.BoolTitleTag || Config.BoolAlbumTag ||
 		    Config.BoolNumerateTag || Config.BoolGenreTag || Config.BoolYearTag || Config.BoolCommentTag) {
-			conv.ArgConv [ pos++ ] = g_strdup ("--add-id3v2");
+			PtrTabArgs [ pos++ ] = g_strdup ("--add-id3v2");
 		}
 		
 		if (Config.BoolArtistTag && param_filelc->tags && param_filelc->tags->Artist && *param_filelc->tags->Artist) {
-			conv.ArgConv [ pos++ ] = g_strdup ("--ta");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Artist);
+			PtrTabArgs [ pos++ ] = g_strdup ("--ta");
+			PtrTabArgs [ pos++ ] = g_strdup (param_filelc->tags->Artist);
 		}
 		
 		if (Config.BoolTitleTag && param_filelc->tags && param_filelc->tags->Title && *param_filelc->tags->Title) {
-			conv.ArgConv [ pos++ ] = g_strdup ("--tt");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Title);
+			PtrTabArgs [ pos++ ] = g_strdup ("--tt");
+			PtrTabArgs [ pos++ ] = g_strdup (param_filelc->tags->Title);
 		}
 		
 		if (Config.BoolAlbumTag && param_filelc->tags && param_filelc->tags->Album && *param_filelc->tags->Album) {
-			conv.ArgConv [ pos++ ] = g_strdup ("--tl");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Album);
+			PtrTabArgs [ pos++ ] = g_strdup ("--tl");
+			PtrTabArgs [ pos++ ] = g_strdup (param_filelc->tags->Album);
 		}
 		
 		if (Config.BoolNumerateTag && param_filelc->tags && param_filelc->tags->Number && *param_filelc->tags->Number) {
-			conv.ArgConv [ pos++ ] = g_strdup ("--tn");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Number);
+			PtrTabArgs [ pos++ ] = g_strdup ("--tn");
+			PtrTabArgs [ pos++ ] = g_strdup (param_filelc->tags->Number);
 		}
 		
 		if (Config.BoolGenreTag && param_filelc->tags && param_filelc->tags->Genre && *param_filelc->tags->Genre) {
@@ -393,38 +412,38 @@ void filelc_get_command_line (PARAM_FILELC *param_filelc)
 			if (value < 0 || value > 147) value = 147;
 			/*New = g_list_append (New, g_strdup ("--tg"));
 			New = g_list_append (New, g_strdup_printf ("%d", value));*/
-			conv.ArgConv [ pos++ ] = g_strdup ("--tg");
-			conv.ArgConv [ pos++ ] = g_strdup_printf ("%d", value);
+			PtrTabArgs [ pos++ ] = g_strdup ("--tg");
+			PtrTabArgs [ pos++ ] = g_strdup_printf ("%d", value);
 		}
 		
 		if (Config.BoolYearTag && param_filelc->tags && param_filelc->tags->Year && *param_filelc->tags->Year) {
-			conv.ArgConv [ pos++ ] = g_strdup ("--ty");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Year);
+			PtrTabArgs [ pos++ ] = g_strdup ("--ty");
+			PtrTabArgs [ pos++ ] = g_strdup (param_filelc->tags->Year);
 		}
 		
 		if (Config.BoolCommentTag && param_filelc->tags && param_filelc->tags->Comment && *param_filelc->tags->Comment) {
-			conv.ArgConv [ pos++ ] = g_strdup ("--tc");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Comment);
+			PtrTabArgs [ pos++ ] = g_strdup ("--tc");
+			PtrTabArgs [ pos++ ] = g_strdup (param_filelc->tags->Comment);
 		}
 		
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filesrc);
-		conv.ArgConv [ pos++ ] = g_strdup ("-o");
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filedest);
-		conv.ArgConv [ pos++ ] = NULL;
+		PtrTabArgs [ pos++ ] = g_strdup (param_filelc->filesrc);
+		PtrTabArgs [ pos++ ] = g_strdup ("-o");
+		PtrTabArgs [ pos++ ] = g_strdup (param_filelc->filedest);
+		PtrTabArgs [ pos++ ] = NULL;
 	}
 	else if (param_filelc->type_conv == OGGENC_WAV_TO_OGG || param_filelc->type_conv == OGGENC_FLAC_TO_OGG) {
 
 		gchar	**Larrbuf = NULL;
 		gint	  i;
 		
-		pos = filelc_get_command_line_nice ();
-		conv.ArgConv [ pos++ ] = g_strdup ("oggenc");
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filesrc);
+		pos = 3;
+		PtrTabArgs[ pos++ ] = g_strdup ("oggenc");
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filesrc);
 		
 		if (param_filelc->PtrStrBitrate != NULL) {
 			Larrbuf = g_strsplit (param_filelc->PtrStrBitrate, " ", 0);
 			for (i=0; Larrbuf[i]; i++) {
-				conv.ArgConv [ pos++ ] = g_strdup (Larrbuf[i]);
+				PtrTabArgs[ pos++ ] = g_strdup (Larrbuf[i]);
 			}
 			g_strfreev(Larrbuf);
 			g_free (param_filelc->PtrStrBitrate);
@@ -432,300 +451,301 @@ void filelc_get_command_line (PARAM_FILELC *param_filelc)
 		}
 
 		if (Config.BoolArtistTag && param_filelc->tags && param_filelc->tags->Artist && *param_filelc->tags->Artist) {
-			conv.ArgConv [ pos++ ] = g_strdup ("-a");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Artist);
+			PtrTabArgs[ pos++ ] = g_strdup ("-a");
+			PtrTabArgs[ pos++ ] = g_strdup ("-a");
 		}
 		if (Config.BoolTitleTag && param_filelc->tags && param_filelc->tags->Title && *param_filelc->tags->Title) {
-			conv.ArgConv [ pos++ ] = g_strdup ("-t");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Title);
+			PtrTabArgs[ pos++ ] = g_strdup ("-t");
+			PtrTabArgs[ pos++ ] = g_strdup (param_filelc->tags->Title);
 		}
 		if (Config.BoolAlbumTag && param_filelc->tags && param_filelc->tags->Album && *param_filelc->tags->Album) {
-			conv.ArgConv [ pos++ ] = g_strdup ("-l");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Album);
+			PtrTabArgs[ pos++ ] = g_strdup ("-l");
+			PtrTabArgs[ pos++ ] = g_strdup (param_filelc->tags->Album);
 		}
 		if (Config.BoolNumerateTag && param_filelc->tags && param_filelc->tags->Number && *param_filelc->tags->Number) {
-			conv.ArgConv [ pos++ ] = g_strdup ("-N");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Number);
+			PtrTabArgs[ pos++ ] = g_strdup ("-N");
+			PtrTabArgs[ pos++ ] = g_strdup (param_filelc->tags->Number);
 		}
 		if (Config.BoolGenreTag && param_filelc->tags && param_filelc->tags->Genre && *param_filelc->tags->Genre) {
-			conv.ArgConv [ pos++ ] = g_strdup ("-G");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Genre);
+			PtrTabArgs[ pos++ ] = g_strdup ("-G");
+			PtrTabArgs[ pos++ ] = g_strdup (param_filelc->tags->Genre);
 		}
 		if (Config.BoolYearTag && param_filelc->tags && param_filelc->tags->Year && *param_filelc->tags->Year) {
-			conv.ArgConv [ pos++ ] = g_strdup ("--date");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Year);
+			PtrTabArgs[ pos++ ] = g_strdup ("--date");
+			PtrTabArgs[ pos++ ] = g_strdup (param_filelc->tags->Year);
 		}
 		if (Config.BoolCommentTag && param_filelc->tags && param_filelc->tags->Comment && *param_filelc->tags->Comment) {
-			conv.ArgConv [ pos++ ] = g_strdup ("-c");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Comment);
+			PtrTabArgs[ pos++ ] = g_strdup ("-c");
+			PtrTabArgs[ pos++ ] = g_strdup (param_filelc->tags->Comment);
 		}
 
-		conv.ArgConv [ pos++ ] = g_strdup ("-o");
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filedest);
-		conv.ArgConv [ pos++ ] = NULL;
+		PtrTabArgs[ pos++ ] = g_strdup ("-o");
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filedest);
+		PtrTabArgs[ pos++ ] = NULL;
 	}
 	else if (param_filelc->type_conv == FLAC_WAV_TO_FLAC || param_filelc->type_conv == FLAC_FLAC_TO_WAV) {
 		
-		pos = filelc_get_command_line_nice ();
-		conv.ArgConv [ pos++ ] = g_strdup ("flac");
-		conv.ArgConv [ pos++ ] = g_strdup_printf ("%s", optionsFlac_get_compression_level_flac ());
+		pos = 3;
+		PtrTabArgs[ pos++ ] = g_strdup ("flac");
+		PtrTabArgs[ pos++ ] = g_strdup_printf ("%s", optionsFlac_get_compression_level_flac ());
 		
 		if (Config.BoolArtistTag && param_filelc->tags && param_filelc->tags->Artist && *param_filelc->tags->Artist) {
-			conv.ArgConv [ pos++ ] = g_strdup ("-T");
-			conv.ArgConv [ pos++ ] = g_strdup_printf ("artist=%s",param_filelc->tags->Artist);
+			PtrTabArgs[ pos++ ] = g_strdup ("-T");
+			PtrTabArgs[ pos++ ] = g_strdup_printf ("artist=%s",param_filelc->tags->Artist);
 		}
 		if (Config.BoolTitleTag && param_filelc->tags && param_filelc->tags->Title && *param_filelc->tags->Title) {
-			conv.ArgConv [ pos++ ] = g_strdup ("-T");
-			conv.ArgConv [ pos++ ] = g_strdup_printf ("title=%s", param_filelc->tags->Title);
+			PtrTabArgs[ pos++ ] = g_strdup ("-T");
+			PtrTabArgs[ pos++ ] = g_strdup_printf ("title=%s", param_filelc->tags->Title);
 		}
 		if (Config.BoolAlbumTag && param_filelc->tags && param_filelc->tags->Album && *param_filelc->tags->Album) {
-			conv.ArgConv [ pos++ ] = g_strdup ("-T");
-			conv.ArgConv [ pos++ ] = g_strdup_printf ("album=%s", param_filelc->tags->Album);
+			PtrTabArgs[ pos++ ] = g_strdup ("-T");
+			PtrTabArgs[ pos++ ] = g_strdup_printf ("album=%s", param_filelc->tags->Album);
 		}
 		if (Config.BoolNumerateTag && param_filelc->tags && param_filelc->tags->IntNumber > -1) {
-			conv.ArgConv [ pos++ ] = g_strdup ("-T");
-			conv.ArgConv [ pos++ ] = g_strdup_printf ("tracknumber=%d", param_filelc->tags->IntNumber);
+			PtrTabArgs[ pos++ ] = g_strdup ("-T");
+			PtrTabArgs[ pos++ ] = g_strdup_printf ("tracknumber=%d", param_filelc->tags->IntNumber);
 		}
 		if (Config.BoolGenreTag && param_filelc->tags && param_filelc->tags->Genre && *param_filelc->tags->Genre) {
-			conv.ArgConv [ pos++ ] = g_strdup ("-T");
-			conv.ArgConv [ pos++ ] = g_strdup_printf ("genre=%s", param_filelc->tags->Genre);
+			PtrTabArgs[ pos++ ] = g_strdup ("-T");
+			PtrTabArgs[ pos++ ] = g_strdup_printf ("genre=%s", param_filelc->tags->Genre);
 		}
 		if (Config.BoolYearTag && param_filelc->tags && param_filelc->tags->Year && *param_filelc->tags->Year) {
-			conv.ArgConv [ pos++ ] = g_strdup ("-T");
-			conv.ArgConv [ pos++ ] = g_strdup_printf ("date=%s", param_filelc->tags->Year);
+			PtrTabArgs[ pos++ ] = g_strdup ("-T");
+			PtrTabArgs[ pos++ ] = g_strdup_printf ("date=%s", param_filelc->tags->Year);
 		}
 		if (Config.BoolCommentTag && param_filelc->tags && param_filelc->tags->Comment && *param_filelc->tags->Comment) {
-			conv.ArgConv [ pos++ ] = g_strdup ("-T");
-			conv.ArgConv [ pos++ ] = g_strdup_printf ("Description=%s",param_filelc->tags->Comment);
+			PtrTabArgs[ pos++ ] = g_strdup ("-T");
+			PtrTabArgs[ pos++ ] = g_strdup_printf ("Description=%s",param_filelc->tags->Comment);
 		}
 		
-		if (param_filelc->type_conv == FLAC_FLAC_TO_WAV) conv.ArgConv [ pos++ ] = g_strdup ("-d");
+		if (param_filelc->type_conv == FLAC_FLAC_TO_WAV) PtrTabArgs [ pos++ ] = g_strdup ("-d");
 		
-		conv.ArgConv [ pos++ ] = g_strdup ("-f");
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filesrc);
-		conv.ArgConv [ pos++ ] = g_strdup ("-o");
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filedest);
-		conv.ArgConv [ pos++ ] = NULL;
+		PtrTabArgs[ pos++ ] = g_strdup ("-f");
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filesrc);
+		PtrTabArgs[ pos++ ] = g_strdup ("-o");
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filedest);
+		PtrTabArgs[ pos++ ] = NULL;
 	}
 	else if (param_filelc->type_conv == FAAC_WAV_TO_M4A) {
 
 		gchar *Ptr = NULL;
 		
-		pos = filelc_get_command_line_nice ();
-		conv.ArgConv [ pos++ ] = g_strdup ("faac");
+		pos = 3;
+		PtrTabArgs [ pos++ ] = g_strdup ("faac");
 		
 		// filelc_analyse_line (entry, New, param_filelc->tags);
 		// -----------------------------------------------------
 		
 		if ('-' == *OptionsFaac_get_faac_conteneur ()) {
-			conv.ArgConv [ pos++ ] = g_strdup (OptionsFaac_get_faac_conteneur ());
+			PtrTabArgs [ pos++ ] = g_strdup (OptionsFaac_get_faac_conteneur ());
 		}
 		
 		Ptr = OptionsFaac_get_faac_set_choice_vbr_abr ();
 		if ( *(Ptr + 1) == 'b') {
-			conv.ArgConv [ pos++ ] = g_strdup ("-b");
+			PtrTabArgs [ pos++ ] = g_strdup ("-b");
 		}
 		else {
-			conv.ArgConv [ pos++ ] = g_strdup ("-q");
+			PtrTabArgs [ pos++ ] = g_strdup ("-q");
 		}
-		conv.ArgConv [ pos++ ] = g_strdup_printf ("%s", (Ptr +3));
+		PtrTabArgs [ pos++ ] = g_strdup_printf ("%s", (Ptr +3));
 		
 		
 		if (Config.BoolArtistTag && param_filelc->tags && param_filelc->tags->Artist && *param_filelc->tags->Artist) {
-			conv.ArgConv [ pos++ ] = g_strdup ("--artist");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Artist);
+			PtrTabArgs [ pos++ ] = g_strdup ("--artist");
+			PtrTabArgs [ pos++ ] = g_strdup (param_filelc->tags->Artist);
 		}
 		if (Config.BoolTitleTag && param_filelc->tags && param_filelc->tags->Title && *param_filelc->tags->Title) {
-			conv.ArgConv [ pos++ ] = g_strdup ("--title");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Title);
+			PtrTabArgs [ pos++ ] = g_strdup ("--title");
+			PtrTabArgs [ pos++ ] = g_strdup (param_filelc->tags->Title);
 		}
 		if (Config.BoolAlbumTag && param_filelc->tags && param_filelc->tags->Album && *param_filelc->tags->Album) {
-			conv.ArgConv [ pos++ ] = g_strdup ("--album");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Album);
+			PtrTabArgs [ pos++ ] = g_strdup ("--album");
+			PtrTabArgs [ pos++ ] = g_strdup (param_filelc->tags->Album);
 		}
 		if (Config.BoolGenreTag && param_filelc->tags && param_filelc->tags->Genre && *param_filelc->tags->Genre) {
-			conv.ArgConv [ pos++ ] = g_strdup ("--genre");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Genre);
+			PtrTabArgs [ pos++ ] = g_strdup ("--genre");
+			PtrTabArgs [ pos++ ] = g_strdup (param_filelc->tags->Genre);
 		}
 		if (Config.BoolYearTag && param_filelc->tags && param_filelc->tags->Year && *param_filelc->tags->Year) {
-			conv.ArgConv [ pos++ ] = g_strdup ("--year");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Year);
+			PtrTabArgs [ pos++ ] = g_strdup ("--year");
+			PtrTabArgs [ pos++ ] = g_strdup (param_filelc->tags->Year);
 		}
 		if (Config.BoolNumerateTag && param_filelc->tags && param_filelc->tags->IntNumber > -1) {
-			conv.ArgConv [ pos++ ] = g_strdup ("--track");
-			conv.ArgConv [ pos++ ] = g_strdup_printf ("%d", param_filelc->tags->IntNumber);
+			PtrTabArgs [ pos++ ] = g_strdup ("--track");
+			PtrTabArgs [ pos++ ] = g_strdup_printf ("%d", param_filelc->tags->IntNumber);
 		}
 		if (Config.BoolCommentTag && param_filelc->tags && param_filelc->tags->Comment && *param_filelc->tags->Comment) {
-			conv.ArgConv [ pos++ ] = g_strdup ("--comment");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Comment);
+			PtrTabArgs [ pos++ ] = g_strdup ("--comment");
+			PtrTabArgs [ pos++ ] = g_strdup (param_filelc->tags->Comment);
 		}
 
 		// -----------------
 		
-		conv.ArgConv [ pos++ ] = g_strdup ("-o");
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filedest);
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filesrc);
-		conv.ArgConv [ pos++ ] = NULL;
+		PtrTabArgs [ pos++ ] = g_strdup ("-o");
+		PtrTabArgs [ pos++ ] = g_strdup (param_filelc->filedest);
+		PtrTabArgs [ pos++ ] = g_strdup (param_filelc->filesrc);
+		PtrTabArgs [ pos++ ] = NULL;
 	}
 	else if (param_filelc->type_conv == MPPENC_WAV_TO_MPC) {
 		
-		pos = filelc_get_command_line_nice ();
-		conv.ArgConv [ pos++ ] = g_strdup (prginit_get_name (NMR_musepack_tools_mppenc));
-		conv.ArgConv [ pos++ ] = g_strdup ("--verbose");
-		conv.ArgConv [ pos++ ] = g_strdup ("--overwrite");
-		conv.ArgConv [ pos++ ] = g_strdup (optionsMusepack_get_quality_mppenc ());
+		pos = 3;
+		PtrTabArgs[ pos++ ] = g_strdup (prginit_get_name (NMR_musepack_tools_mppenc));
+		PtrTabArgs[ pos++ ] = g_strdup ("--verbose");
+		PtrTabArgs[ pos++ ] = g_strdup ("--overwrite");
+		PtrTabArgs[ pos++ ] = g_strdup (optionsMusepack_get_quality_mppenc ());
 
 		if (Config.BoolArtistTag && param_filelc->tags && param_filelc->tags->Artist && *param_filelc->tags->Artist) {
-			conv.ArgConv [ pos++ ] = g_strdup ("--artist");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Artist);
+			PtrTabArgs[ pos++ ] = g_strdup ("--artist");
+			PtrTabArgs[ pos++ ] = g_strdup (param_filelc->tags->Artist);
 		}
 		if (Config.BoolTitleTag && param_filelc->tags && param_filelc->tags->Title && *param_filelc->tags->Title) {
-			conv.ArgConv [ pos++ ] = g_strdup ("--title");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Title);
+			PtrTabArgs[ pos++ ] = g_strdup ("--title");
+			PtrTabArgs[ pos++ ] = g_strdup (param_filelc->tags->Title);
 		}
 		if (Config.BoolAlbumTag && param_filelc->tags && param_filelc->tags->Album && *param_filelc->tags->Album) {
-			conv.ArgConv [ pos++ ] = g_strdup ("--album");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Album);
+			PtrTabArgs[ pos++ ] = g_strdup ("--album");
+			PtrTabArgs[ pos++ ] = g_strdup (param_filelc->tags->Album);
 		}
 		if (Config.BoolGenreTag && param_filelc->tags && param_filelc->tags->Genre && *param_filelc->tags->Genre) {
-			conv.ArgConv [ pos++ ] = g_strdup ("--genre");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Genre);
+			PtrTabArgs[ pos++ ] = g_strdup ("--genre");
+			PtrTabArgs[ pos++ ] = g_strdup (param_filelc->tags->Genre);
 		}
 		if (Config.BoolYearTag && param_filelc->tags && param_filelc->tags->Year && *param_filelc->tags->Year) {
-			conv.ArgConv [ pos++ ] = g_strdup ("--year");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Year);
+			PtrTabArgs[ pos++ ] = g_strdup ("--year");
+			PtrTabArgs[ pos++ ] = g_strdup (param_filelc->tags->Year);
 		}
 		if (Config.BoolNumerateTag && param_filelc->tags && param_filelc->tags->Number && *param_filelc->tags->Number) {
-			conv.ArgConv [ pos++ ] = g_strdup ("--track");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Number);
+			PtrTabArgs[ pos++ ] = g_strdup ("--track");
+			PtrTabArgs[ pos++ ] = g_strdup (param_filelc->tags->Number);
 		}
 		if (Config.BoolCommentTag && param_filelc->tags && param_filelc->tags->Comment && *param_filelc->tags->Comment) {
-			conv.ArgConv [ pos++ ] = g_strdup ("--comment");
-			conv.ArgConv [ pos++ ] = g_strdup (param_filelc->tags->Comment);
+			PtrTabArgs[ pos++ ] = g_strdup ("--comment");
+			PtrTabArgs[ pos++ ] = g_strdup (param_filelc->tags->Comment);
 		}
 		
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filesrc);
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filedest);
-		conv.ArgConv [ pos++ ] = NULL;
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filesrc);
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filedest);
+		PtrTabArgs[ pos++ ] = NULL;
 	}
 	else if (param_filelc->type_conv == MAC_WAV_TO_APE || param_filelc->type_conv == MAC_APE_TO_WAV) {
 		
-		pos = filelc_get_command_line_nice ();
-		conv.ArgConv [ pos++ ] = g_strdup (prginit_get_name (NMR_mac));
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filesrc);
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filedest);
+		pos = 3;
+		PtrTabArgs[ pos++ ] = g_strdup (prginit_get_name (NMR_mac));	
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filesrc);
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filedest);
 		
 		if (param_filelc->type_conv == MAC_APE_TO_WAV) {
-			conv.ArgConv [ pos++ ] = g_strdup ("-d");
+			PtrTabArgs[ pos++ ] = g_strdup ("-d");
 		}
 		else if (param_filelc->type_conv == MAC_WAV_TO_APE) {
-			conv.ArgConv [ pos++ ] = g_strdup (optionsApe_get_compression_level_ape ());
+			PtrTabArgs[ pos++ ] = g_strdup (optionsApe_get_compression_level_ape ());
 		}
-		conv.ArgConv [ pos++ ] = NULL;
+		PtrTabArgs[ pos++ ] = NULL;
 	}
 	else if (param_filelc->type_conv == WAVPACK_WAV_TO_WAVPACK) {
 		
-		pos = filelc_get_command_line_nice ();
-		conv.ArgConv [ pos++ ] = g_strdup ("wavpack");
-		conv.ArgConv [ pos++ ] = g_strdup ("-y");
-		
+		pos = 3;
+		PtrTabArgs[ pos++ ] = g_strdup ("wavpack");
+		PtrTabArgs[ pos++ ] = g_strdup ("-y");
+				
 		if (*optionsWavpack_get_wavpack_compression () != '\0')
-			conv.ArgConv [ pos++ ] = g_strdup (optionsWavpack_get_wavpack_compression ());
-		conv.ArgConv [ pos++ ] = g_strdup (optionsWavpack_get_wavpack_sound ());
+			PtrTabArgs[ pos++ ] = g_strdup (optionsWavpack_get_wavpack_compression ());
+		PtrTabArgs[ pos++ ] = g_strdup (optionsWavpack_get_wavpack_sound ());
 		
 		if (*optionsWavpac_get_wavpack_hybride () != '\0') {
-			conv.ArgConv [ pos++ ] = g_strdup (optionsWavpac_get_wavpack_hybride ());
+			PtrTabArgs[ pos++ ] = g_strdup (optionsWavpac_get_wavpack_hybride ());
 			if (*optionsWavpack_get_wavpack_correction_file () != '\0') {
-				conv.ArgConv [ pos++ ] = g_strdup (optionsWavpack_get_wavpack_correction_file ());
+				PtrTabArgs[ pos++ ] = g_strdup (optionsWavpack_get_wavpack_correction_file ());
 			}
 			if (*optionsWavpack_get_wavpack_maximum_compression () != '\0') {
-				conv.ArgConv [ pos++ ] = g_strdup (optionsWavpack_get_wavpack_maximum_compression ());
+				PtrTabArgs[ pos++ ] = g_strdup (optionsWavpack_get_wavpack_maximum_compression ());
 			}
 		}
 		if (*optionsWavpack_get_wavpack_signature_md5 () != '\0') {
-			conv.ArgConv [ pos++ ] = g_strdup (optionsWavpack_get_wavpack_signature_md5 ());
+			PtrTabArgs[ pos++ ] = g_strdup (optionsWavpack_get_wavpack_signature_md5 ());
 		}
 		if (*optionsWavpack_get_wavpack_extra_encoding () != '\0') {
-			conv.ArgConv [ pos++ ] = g_strdup (optionsWavpack_get_wavpack_extra_encoding ());
+			PtrTabArgs[ pos++ ] = g_strdup (optionsWavpack_get_wavpack_extra_encoding ());
 		}
 
 		if (Config.BoolArtistTag && param_filelc->tags && param_filelc->tags->Artist && *param_filelc->tags->Artist) {
-			conv.ArgConv [ pos++ ] = g_strdup ("-w");
-			conv.ArgConv [ pos++ ] = g_strdup_printf ("Artist=%s", param_filelc->tags->Artist);
+			PtrTabArgs[ pos++ ] = g_strdup ("-w");
+			PtrTabArgs[ pos++ ] = g_strdup_printf ("Artist=%s", param_filelc->tags->Artist);
 		}
 		if (Config.BoolTitleTag && param_filelc->tags && param_filelc->tags->Title && *param_filelc->tags->Title) {
-			conv.ArgConv [ pos++ ] = g_strdup ("-w");
-			conv.ArgConv [ pos++ ] = g_strdup_printf ("Title=%s", param_filelc->tags->Title);
+			PtrTabArgs[ pos++ ] = g_strdup ("-w");
+			PtrTabArgs[ pos++ ] = g_strdup_printf ("Title=%s", param_filelc->tags->Title);
 		}
 		if (Config.BoolAlbumTag && param_filelc->tags && param_filelc->tags->Album && *param_filelc->tags->Album) {
-			conv.ArgConv [ pos++ ] = g_strdup ("-w");
-			conv.ArgConv [ pos++ ] = g_strdup_printf ("Album=%s", param_filelc->tags->Album);
+			PtrTabArgs[ pos++ ] = g_strdup ("-w");
+			PtrTabArgs[ pos++ ] = g_strdup_printf ("Album=%s", param_filelc->tags->Album);
 		}
 		if (Config.BoolGenreTag && param_filelc->tags && param_filelc->tags->Genre && *param_filelc->tags->Genre) {
-			conv.ArgConv [ pos++ ] = g_strdup ("-w");
-			conv.ArgConv [ pos++ ] = g_strdup_printf ("Genre=%s", param_filelc->tags->Genre);
+			PtrTabArgs[ pos++ ] = g_strdup ("-w");
+			PtrTabArgs[ pos++ ] = g_strdup_printf ("Genre=%s", param_filelc->tags->Genre);
 		}
 		if (Config.BoolYearTag && param_filelc->tags && param_filelc->tags->Year && *param_filelc->tags->Year) {
-			conv.ArgConv [ pos++ ] = g_strdup ("-w");
-			conv.ArgConv [ pos++ ] = g_strdup_printf ("Year=%s", param_filelc->tags->Year);
+			PtrTabArgs[ pos++ ] = g_strdup ("-w");
+			PtrTabArgs[ pos++ ] = g_strdup_printf ("Year=%s", param_filelc->tags->Year);
 		}
 		if (Config.BoolNumerateTag && param_filelc->tags && param_filelc->tags->Number && *param_filelc->tags->Number) {
-			conv.ArgConv [ pos++ ] = g_strdup ("-w");
-			conv.ArgConv [ pos++ ] = g_strdup_printf ("Track=%s", param_filelc->tags->Number);
+			PtrTabArgs[ pos++ ] = g_strdup ("-w");
+			PtrTabArgs[ pos++ ] = g_strdup_printf ("Track=%s", param_filelc->tags->Number);
 		}
 		if (Config.BoolCommentTag && param_filelc->tags &&param_filelc->tags->Comment && *param_filelc->tags->Comment) {
-			conv.ArgConv [ pos++ ] = g_strdup ("-w");
-			conv.ArgConv [ pos++ ] = g_strdup_printf ("Comment=%s", param_filelc->tags->Comment);
+			PtrTabArgs[ pos++ ] = g_strdup ("-w");
+			PtrTabArgs[ pos++ ] = g_strdup_printf ("Comment=%s", param_filelc->tags->Comment);
 		}
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filesrc);
-		conv.ArgConv [ pos++ ] = g_strdup ("-o");
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filedest);
-		conv.ArgConv [ pos++ ] = NULL;
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filesrc);
+		PtrTabArgs[ pos++ ] = g_strdup ("-o");
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filedest);
+		PtrTabArgs[ pos++ ] = NULL;
 	}
 	else if (param_filelc->type_conv == CDPARANOIA_CD_TO_WAV) {
 		
-		pos = filelc_get_command_line_nice ();
-		conv.ArgConv [ pos++ ] = g_strdup ("cdparanoia");
-		conv.ArgConv [ pos++ ] = g_strdup ("-e");
-		conv.ArgConv [ pos++ ] = g_strdup ("-d");
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->cdrom);
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->num_track);
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filedest);
-		conv.ArgConv [ pos++ ] = NULL;
+		pos = 3;
+		PtrTabArgs[ pos++ ] = g_strdup ("cdparanoia");
+		PtrTabArgs[ pos++ ] = g_strdup ("-e");
+		PtrTabArgs[ pos++ ] = g_strdup ("-d");
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->cdrom);
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->num_track);
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filedest);
+		PtrTabArgs[ pos++ ] = NULL;
 	}
 	else if (param_filelc->type_conv == CDDA2WAV_CD_TO_WAV) {
 		
 		// cdda2wav -D /dev/hda -O wav -t 7
-		//
-		pos = filelc_get_command_line_nice ();
-		conv.ArgConv [ pos++ ] = g_strdup ("cdda2wav");
-		conv.ArgConv [ pos++ ] = g_strdup ("-D");
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->cdrom);
-		conv.ArgConv [ pos++ ] = g_strdup ("-O");
-		conv.ArgConv [ pos++ ] = g_strdup ("wav");
-		conv.ArgConv [ pos++ ] = g_strdup ("-t");
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->num_track);
-		conv.ArgConv [ pos++ ] = NULL;
+		pos = 3;
+		PtrTabArgs[ pos++ ] = g_strdup ("cdda2wav");
+		PtrTabArgs[ pos++ ] = g_strdup ("-D");
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->cdrom);
+		PtrTabArgs[ pos++ ] = g_strdup ("-O");
+		PtrTabArgs[ pos++ ] = g_strdup ("wav");
+		PtrTabArgs[ pos++ ] = g_strdup ("-t");
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->num_track);
+		PtrTabArgs[ pos++ ] = NULL;
 	}
 	else if (param_filelc->type_conv == AACPLUSENC_WAV_TO_AAC) {
 		
-		pos = filelc_get_command_line_nice ();
-		conv.ArgConv [ pos++ ] = g_strdup ("aacplusenc");
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filesrc);
-		conv.ArgConv [ pos++ ] = g_strdup (param_filelc->filedest);
-
-		if (param_filelc->tags->bool_tag_cd == TRUE) {
-			conv.ArgConv [ pos++ ] = g_strdup_printf ("%d", optionsaacplusenc_get_bitrate_stereo ());
+		pos = 3;
+		PtrTabArgs[ pos++ ] = g_strdup ("aacplusenc");
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filesrc);
+		PtrTabArgs[ pos++ ] = g_strdup (param_filelc->filedest);
+		
+		if( NULL != param_filelc->tags && TRUE == param_filelc->tags->bool_tag_cd ) {
+			PtrTabArgs[ pos++ ] = g_strdup_printf ("%d", optionsaacplusenc_get_bitrate_stereo ());
 		}
 		else {
 			if (tagswav_file_is_mono (param_filelc->filesrc) == TRUE) {
-				conv.ArgConv [ pos++ ] = g_strdup_printf ("%d", optionsaacplusenc_get_bitrate_mono ());
+				PtrTabArgs[ pos++ ] = g_strdup_printf ("%d", optionsaacplusenc_get_bitrate_mono ());
 			} else {
-				conv.ArgConv [ pos++ ] = g_strdup_printf ("%d", optionsaacplusenc_get_bitrate_stereo ());
+				PtrTabArgs[ pos++ ] = g_strdup_printf ("%d", optionsaacplusenc_get_bitrate_stereo ());
 			}
 		}
-		conv.ArgConv [ pos++ ] = NULL;
+		PtrTabArgs[ pos++ ] = NULL;
 	}
+	
+	return( (gchar **)PtrTabArgs );
 }
 // 
 // 
