@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2012 by Claude Bulin
+ *  copyright : (C) 2003 - 2013 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -371,7 +371,7 @@ gboolean FileMp3Ogg_del_file_clicked (void)
 			}
 			list = g_list_next (list);
 		}
-		gtk_tree_selection_unselect_all (var_file_mp3ogg.Adr_Line_Selected);
+		// gtk_tree_selection_unselect_all (var_file_mp3ogg.Adr_Line_Selected);
 	}
 	return (BoolPrint);
 }
@@ -440,37 +440,23 @@ void FileMp3Ogg_affiche_glist (void)
 {
 	DETAIL		*detail = NULL;
 	GList		*List = NULL;
-	GList		*FreegList = NULL;
 	GtkTreeIter	iter;
 	GtkAdjustment	*Adj = NULL;
 	gdouble		AdjValue;
-	gint		*TabInt = NULL;		// TABLEAU DES LIGNES EN SELECTION
-	gint		Cpt = 0;		// INDICE DANS LE TABLEAU
 	gint		Line = 0;		// LIGNE EN COURS
 	INFO_MP3	*info_mp3 = NULL;
 	INFO_OGG	*info_ogg = NULL;
 	gchar		*StrInfo = NULL;
 	gchar		*PtrBitrate = NULL;
 	gchar		*NameDest = NULL;
+	gint		NumLineSelected = -1;
+	gboolean	BoolNumLineSelected = FALSE;
 
-	// LIBERATION LIGNE(S) DU GLIST SI NECESSARE
-	// 
-	List = g_list_first (entetefile);
-	while (List) {
-		if ((detail = (DETAIL *)List->data) && TRUE == detail->BoolRemove) {
-			FreegList = List;
-			FreegList->data = NULL;
-			List = g_list_next (List);
-			entetefile = g_list_remove_link (entetefile, FreegList);
-			List = g_list_first (entetefile);
-			continue;
-		}
-		List = g_list_next (List);
-	}
-	
 	// RECUP SELECTION
 	// 
-	TabInt = libutils_get_tab_selected_line (var_file_mp3ogg.Adr_Line_Selected, var_file_mp3ogg.Adr_Tree_Model);
+	NumLineSelected = libutils_get_first_line_is_selected( var_file_mp3ogg.Adr_Line_Selected, var_file_mp3ogg.Adr_Tree_Model );
+	
+	gtk_tree_selection_unselect_all (var_file_mp3ogg.Adr_Line_Selected);
 
 	// DELETE TREEVIEW
 	// 
@@ -483,7 +469,6 @@ void FileMp3Ogg_affiche_glist (void)
 	
 	// AFFICHAGE DE LA LISTE
 	// 
-	Cpt = 0;
 	Line = 0;
 	List = g_list_first (entetefile);
 	while (List) {
@@ -497,12 +482,10 @@ void FileMp3Ogg_affiche_glist (void)
 			}
 			else {
 				List = g_list_next (List);
-				Line ++;
 				continue;
 			}
 			if (NULL == info_mp3 && NULL == info_ogg) {
 				List = g_list_next (List);
-				Line ++;
 				continue;
 			}
 			
@@ -532,26 +515,26 @@ void FileMp3Ogg_affiche_glist (void)
 			
 			// AFFICHE LES EVENTUELLES LIGNES EN SELECTION
 			// 
-			if (NULL != TabInt) {
-				if (Line == *(TabInt + Cpt)) {
-					gtk_tree_selection_select_iter (var_file_mp3ogg.Adr_Line_Selected, &iter);
-					Cpt ++;
-				}
-				Line ++;
+			if( NumLineSelected == Line ) {
+				gtk_tree_selection_select_iter (var_file_mp3ogg.Adr_Line_Selected, &iter);
+				BoolNumLineSelected = TRUE;
 			}
+			
+			Line ++;
 		}
 		List = g_list_next (List);
 	}
 	
 	// SUPPRESSON TABLEAU DES EVENTUELLES LIGNES EN SELECTION
 	// 
-	if (NULL != TabInt) {
-		g_free (TabInt);
-		TabInt = NULL;
-	}
-	else {
-		if (gtk_tree_model_get_iter_first (var_file_mp3ogg.Adr_Tree_Model, &iter))
+	if( NumLineSelected == -1 ) {
+		if (gtk_tree_model_get_iter_first (var_file_mp3ogg.Adr_Tree_Model, &iter)) {
 			gtk_tree_selection_select_iter (var_file_mp3ogg.Adr_Line_Selected, &iter);
+			BoolNumLineSelected = TRUE;
+		}
+	}
+	if( NumLineSelected > 0 && NULL != entetefile && BoolNumLineSelected == FALSE ) {
+		gtk_tree_selection_select_iter (var_file_mp3ogg.Adr_Line_Selected, &iter);
 	}
 
 	// REAJUSTEMENT DE LA LISTE
