@@ -72,6 +72,7 @@ static void filemp3oggconv_thread (void *arg)
 	PARAM_FILELC	param_filelc;
 	CONV_FIC_MP3OGG	*PConvMp3Ogg;
 	gint		pos;
+	gchar		**PtrTabArgs = NULL;
 	
 	g_print ("\n");
 	g_print ("!-------------------------------------------------!\n");
@@ -110,24 +111,24 @@ static void filemp3oggconv_thread (void *arg)
 					g_print ("DEST   WAV<%s>\n", PConvMp3Ogg->destwav);
 				}
 				
-				pos = filelc_get_command_line_nice ();
-				conv.ArgConv [ pos++ ] = g_strdup ("mplayer");
-				conv.ArgConv [ pos++ ] = g_strdup ("-nojoystick");
-				conv.ArgConv [ pos++ ] = g_strdup ("-nolirc");
-				conv.ArgConv [ pos++ ] = g_strdup ("-novideo");
-				conv.ArgConv [ pos++ ] = g_strdup_printf ("%s", detail->namefile);
-				conv.ArgConv [ pos++ ] = g_strdup ("-ao");
-				conv.ArgConv [ pos++ ] = g_strdup ("pcm");
-				conv.ArgConv [ pos++ ] = g_strdup ("-ao");
-				conv.ArgConv [ pos++ ] = g_strdup_printf ("pcm:file=%s", PConvMp3Ogg->destwav);
-				conv.ArgConv [ pos++ ] = g_strdup ("-af");
-				conv.ArgConv [ pos++ ] = g_strdup ("channels=2");
-				conv.ArgConv [ pos++ ] = g_strdup ("-srate");
-				conv.ArgConv [ pos++ ] = g_strdup ("44100");
-				conv.ArgConv [ pos++ ] = NULL;
-				
-				conv_to_convert (FALSE, MPLAYER_WAV_TO_WAV, "MPLAYER_WAV_TO_WAV");
-				filelc_get_command_line_remove ();
+				PtrTabArgs = filelc_AllocTabArgs();
+				pos = 3;
+				PtrTabArgs [ pos++ ] = g_strdup ("mplayer");
+				PtrTabArgs [ pos++ ] = g_strdup ("-nojoystick");
+				PtrTabArgs [ pos++ ] = g_strdup ("-nolirc");
+				PtrTabArgs [ pos++ ] = g_strdup ("-novideo");
+				PtrTabArgs [ pos++ ] = g_strdup_printf ("%s", detail->namefile);
+				PtrTabArgs [ pos++ ] = g_strdup ("-ao");
+				PtrTabArgs [ pos++ ] = g_strdup ("pcm");
+				PtrTabArgs [ pos++ ] = g_strdup ("-ao");
+				PtrTabArgs [ pos++ ] = g_strdup_printf ("pcm:file=%s", PConvMp3Ogg->destwav);
+				PtrTabArgs [ pos++ ] = g_strdup ("-af");
+				PtrTabArgs [ pos++ ] = g_strdup ("channels=2");
+				PtrTabArgs [ pos++ ] = g_strdup ("-srate");
+				PtrTabArgs [ pos++ ] = g_strdup ("44100");
+				PtrTabArgs [ pos++ ] = NULL;
+				conv_to_convert( PtrTabArgs, FALSE, MPLAYER_WAV_TO_WAV, "MPLAYER_WAV_TO_WAV");
+				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 				
 				if( TRUE == libutils_test_file_exist( PConvMp3Ogg->destwav )) {
 					
@@ -140,9 +141,9 @@ static void filemp3oggconv_thread (void *arg)
 							g_print ("SOURCE MP3<%s>\n", PConvMp3Ogg->destwav);
 							g_print ("DEST   WAV<%s>\n", PConvMp3Ogg->destsox);
 						}
-						conv_with_sox_get_param( PConvMp3Ogg->destwav, PConvMp3Ogg->destsox, "44100", "2", "16" );
-						conv_to_convert (FALSE, SOX_WAV_TO_WAV, "SOX_WAV_TO_WAV");
-						filelc_get_command_line_remove ();
+						PtrTabArgs = conv_with_sox_get_param( PConvMp3Ogg->destwav, PConvMp3Ogg->destsox, "44100", "2", "16" );
+						conv_to_convert( PtrTabArgs, FALSE, SOX_WAV_TO_WAV, "SOX_WAV_TO_WAV");
+						PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 						conv_copy_src_to_dest (PConvMp3Ogg->destsox, PConvMp3Ogg->destwav);
 					
 						// conv.encode_completed ++;
@@ -166,9 +167,9 @@ static void filemp3oggconv_thread (void *arg)
 						param_filelc.BoolSetBitrate       = TRUE;
 						param_filelc.PtrStrBitrate        = popup_get_param_mp3( detail->Mp3_Debit, detail->Mp3_Mode );
 
-						filelc_get_command_line (&param_filelc);
-						conv_to_convert (FALSE, LAME_WAV_TO_MP3, "LAME_WAV_TO_MP3");
-						filelc_get_command_line_remove ();
+						PtrTabArgs = filelc_get_command_line (&param_filelc);
+						conv_to_convert( PtrTabArgs, FALSE, LAME_WAV_TO_MP3, "LAME_WAV_TO_MP3");
+						PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 
 						/* copy SOURCE MP3 -> DESTINATION MP3
 						*  ----------------------------------
@@ -196,23 +197,23 @@ static void filemp3oggconv_thread (void *arg)
 					g_print ("SOURCE MP3<%s>\n", detail->namefile);
 					g_print ("DEST   WAV<%s>\n", PConvMp3Ogg->destwav);
 				}
-				pos = filelc_get_command_line_nice ();
-				conv.ArgConv [ pos++ ] = g_strdup ("mplayer");
-				conv.ArgConv [ pos++ ] = g_strdup ("-nojoystick");
-				conv.ArgConv [ pos++ ] = g_strdup ("-nolirc");
-				conv.ArgConv [ pos++ ] = g_strdup ("-ao");
-				conv.ArgConv [ pos++ ] = g_strdup ("pcm");
-				conv.ArgConv [ pos++ ] = g_strdup_printf ("%s", detail->namefile);
-				conv.ArgConv [ pos++ ] = g_strdup ("-ao");
-				conv.ArgConv [ pos++ ] = g_strdup_printf ("pcm:file=%s", PConvMp3Ogg->destwav);
-				conv.ArgConv [ pos++ ] = g_strdup ("-af");
-				conv.ArgConv [ pos++ ] = g_strdup ("channels=2");
-				conv.ArgConv [ pos++ ] = g_strdup ("-srate");
-				conv.ArgConv [ pos++ ] = g_strdup ("44100");
-				conv.ArgConv [ pos++ ] = NULL;
-
-				conv_to_convert (param_filelc.With_CommandLineUser, MPLAYER_OGG_TO_WAV, "MPLAYER_OGG_TO_WAV");
-				filelc_get_command_line_remove ();
+				PtrTabArgs = filelc_AllocTabArgs();
+				pos = 3;
+				PtrTabArgs [ pos++ ] = g_strdup ("mplayer");
+				PtrTabArgs [ pos++ ] = g_strdup ("-nojoystick");
+				PtrTabArgs [ pos++ ] = g_strdup ("-nolirc");
+				PtrTabArgs [ pos++ ] = g_strdup ("-ao");
+				PtrTabArgs [ pos++ ] = g_strdup ("pcm");
+				PtrTabArgs [ pos++ ] = g_strdup_printf ("%s", detail->namefile);
+				PtrTabArgs [ pos++ ] = g_strdup ("-ao");
+				PtrTabArgs [ pos++ ] = g_strdup_printf ("pcm:file=%s", PConvMp3Ogg->destwav);
+				PtrTabArgs [ pos++ ] = g_strdup ("-af");
+				PtrTabArgs [ pos++ ] = g_strdup ("channels=2");
+				PtrTabArgs [ pos++ ] = g_strdup ("-srate");
+				PtrTabArgs [ pos++ ] = g_strdup ("44100");
+				PtrTabArgs [ pos++ ] = NULL;
+				conv_to_convert( PtrTabArgs, param_filelc.With_CommandLineUser, MPLAYER_OGG_TO_WAV, "MPLAYER_OGG_TO_WAV");
+				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 								
 				if( TRUE == libutils_test_file_exist( PConvMp3Ogg->destwav ) && libutils_get_size_file( PConvMp3Ogg->destwav ) > 0 ) {
 					
@@ -233,9 +234,9 @@ static void filemp3oggconv_thread (void *arg)
 					param_filelc.BoolSetBitrate       = TRUE;
 					param_filelc.PtrStrBitrate        = popup_get_param_ogg( detail->Ogg_Debit, detail->Ogg_Managed, detail->Ogg_Downmix );
 
-					filelc_get_command_line (&param_filelc);
-					conv_to_convert (FALSE, OGGENC_WAV_TO_OGG, "OGGENC_WAV_TO_OGG");
-					filelc_get_command_line_remove ();
+					PtrTabArgs = filelc_get_command_line (&param_filelc);
+					conv_to_convert( PtrTabArgs, FALSE, OGGENC_WAV_TO_OGG, "OGGENC_WAV_TO_OGG");
+					PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 				
 					/* copy SOURCE OGG -> DESTINATION MP3
 					*  ----------------------------------
