@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2012 by Claude Bulin
+ *  copyright : (C) 2003 - 2013 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -431,7 +431,6 @@ void FileTags_set_label_tag_change (void)
 	gchar         *str = NULL;
 	gint           changed = 0;
 	
-	
 	if (NULL == var_file_tags.Adr_label_tag_change) return;
 	tags = FileTags_get_tag (NULL);
 	gtk_widget_set_sensitive (GTK_WIDGET (var_file_tags.Adr_table_tag), tags ? TRUE : FALSE);
@@ -831,7 +830,7 @@ gboolean FileTags_del_file_clicked (void)
 			}
 			list = g_list_next (list);
 		}
-		gtk_tree_selection_unselect_all (var_file_tags.Adr_Line_Selected);
+		// gtk_tree_selection_unselect_all (var_file_tags.Adr_Line_Selected);
 	}
 	return (BoolPrint);
 }
@@ -841,39 +840,25 @@ gboolean FileTags_del_file_clicked (void)
 // FILE_IS_MPC
 // 
 // 
-void FileTags_affiche_glist (void)
+void FileTags_affiche_glist( void )
 {
 	DETAIL		*detail = NULL;
 	GList		*List = NULL;
-	GList		*FreegList = NULL;
 	GtkTreeIter	iter;
 	GtkAdjustment	*Adj = NULL;
 	gdouble		AdjValue;
-	gint		*TabInt = NULL;		// TABLEAU DES LIGNES EN SELECTION
-	gint		Cpt = 0;		// INDICE DANS LE TABLEAU
 	gint		Line = 0;		// LIGNE EN COURS
 	gchar		*NameDest = NULL;
+	gint		NumLineSelected = -1;
+	gboolean	BoolNumLineSelected = FALSE;
 	
 	// PRINT_FUNC_LF();
 	
-	// LIBERATION LIGNE(S) DU GLIST SI NECESSARE
-	// 
-	List = g_list_first (entetefile);
-	while (List) {
-		if (NULL != (detail = (DETAIL *)List->data) && TRUE == detail->BoolRemove) {
-			FreegList = List;
-			FreegList->data = NULL;
-			List = g_list_next (List);
-			entetefile = g_list_remove_link (entetefile, FreegList);
-			List = g_list_first (entetefile);
-			continue;
-		}
-		List = g_list_next (List);
-	}
-	
 	// RECUP SELECTION
 	// 
-	TabInt = libutils_get_tab_selected_line (var_file_tags.Adr_Line_Selected, var_file_tags.Adr_Tree_Model);
+	NumLineSelected = libutils_get_first_line_is_selected( var_file_tags.Adr_Line_Selected, var_file_tags.Adr_Tree_Model );
+
+	gtk_tree_selection_unselect_all (var_file_tags.Adr_Line_Selected);
 
 	// DELETE TREEVIEW
 	// 
@@ -886,7 +871,6 @@ void FileTags_affiche_glist (void)
 	
 	// AFFICHAGE DE LA LISTE
 	// 
-	Cpt = 0;
 	Line = 0;
 	List = g_list_first (entetefile);
 	while (List) {
@@ -897,7 +881,6 @@ void FileTags_affiche_glist (void)
 			    FILE_IS_OGG != detail->type_infosong_file_is &&
 			    FILE_IS_MPC != detail->type_infosong_file_is) {
 				List = g_list_next (List);
-				// Line ++;
 				continue;
 			}
 			
@@ -916,26 +899,28 @@ void FileTags_affiche_glist (void)
 			
 			// AFFICHE LES EVENTUELLES LIGNES EN SELECTION
 			// 
-			if (NULL != TabInt) {
-				if (Line == *(TabInt + Cpt)) {
-					gtk_tree_selection_select_iter (var_file_tags.Adr_Line_Selected, &iter);
-					Cpt ++;
-				}
-				Line ++;
+			if( NumLineSelected == Line ) {
+				gtk_tree_selection_select_iter (var_file_tags.Adr_Line_Selected, &iter);
+				BoolNumLineSelected = TRUE;
 			}
+			
+			Line ++;
 		}
 		List = g_list_next (List);
 	}
 	
 	// SUPPRESSON TABLEAU DES EVENTUELLES LIGNES EN SELECTION
 	// 
-	if (NULL != TabInt) {
-		g_free (TabInt);
-		TabInt = NULL;
-	}
-	else {
-		if (gtk_tree_model_get_iter_first (var_file_tags.Adr_Tree_Model, &iter))
+	
+	if( NumLineSelected == -1 ) {
+		if (gtk_tree_model_get_iter_first (var_file_tags.Adr_Tree_Model, &iter)) {
 			gtk_tree_selection_select_iter (var_file_tags.Adr_Line_Selected, &iter);
+			BoolNumLineSelected = TRUE;
+		}
+	}
+
+	if( NumLineSelected > 0 && NULL != entetefile && BoolNumLineSelected == FALSE ) {
+		gtk_tree_selection_select_iter (var_file_tags.Adr_Line_Selected, &iter);
 	}
 
 	// REAJUSTEMENT DE LA LISTE
