@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2012 by Claude Bulin
+ *  copyright : (C) 2003 - 2013 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -205,7 +205,7 @@ gboolean FileWav_del_file_clicked (void)
 			}
 			list = g_list_next (list);
 		}
-		gtk_tree_selection_unselect_all (var_file_wav.Adr_Line_Selected);
+		// gtk_tree_selection_unselect_all (var_file_wav.Adr_Line_Selected);
 	}
 	return (BoolPrint);
 }
@@ -215,37 +215,23 @@ void FileWav_affiche_glist (void)
 {
 	DETAIL		*detail = NULL;
 	GList		*List = NULL;
-	GList		*FreegList = NULL;
 	GtkTreeIter	iter;
 	GtkAdjustment	*Adj = NULL;
 	gdouble		AdjValue;
-	gint		*TabInt = NULL;		// TABLEAU DES LIGNES EN SELECTION
-	gint		Cpt = 0;		// INDICE DANS LE TABLEAU
 	gint		Line = 0;		// LIGNE EN COURS
 	INFO_WAV	*info = NULL;
 	gchar		*NewHertz = NULL;
 	gchar		*NewVoie = NULL;
 	gchar		*NewBits = NULL;
 	gchar		*NameDest = NULL;
-	
-	// LIBERATION LIGNE(S) DU GLIST SI NECESSARE
-	// 
-	List = g_list_first (entetefile);
-	while (List) {
-		if ((detail = (DETAIL *)List->data) && TRUE == detail->BoolRemove) {
-			FreegList = List;
-			FreegList->data = NULL;
-			List = g_list_next (List);
-			entetefile = g_list_remove_link (entetefile, FreegList);
-			List = g_list_first (entetefile);
-			continue;
-		}
-		List = g_list_next (List);
-	}
+	gint		NumLineSelected = -1;
+	gboolean	BoolNumLineSelected = FALSE;
 	
 	// RECUP SELECTION
 	// 
-	TabInt = libutils_get_tab_selected_line (var_file_wav.Adr_Line_Selected, var_file_wav.Adr_Tree_Model);
+	NumLineSelected = libutils_get_first_line_is_selected( var_file_wav.Adr_Line_Selected, var_file_wav.Adr_Tree_Model );
+	
+	gtk_tree_selection_unselect_all (var_file_wav.Adr_Line_Selected);
 
 	// DELETE TREEVIEW
 	// 
@@ -258,19 +244,16 @@ void FileWav_affiche_glist (void)
 	
 	// AFFICHAGE DE LA LISTE
 	// 
-	Cpt = 0;
 	Line = 0;
 	List = g_list_first (entetefile);
 	while (List) {
 		if (NULL != ((detail = (DETAIL *)List->data)) && FALSE == detail->BoolRemove) {
 			if (FILE_IS_WAV != detail->type_infosong_file_is) {
 				List = g_list_next (List);
-				// Line ++;
 				continue;
 			}
 			if (NULL == (info = (INFO_WAV *)detail->info)) {
 				List = g_list_next (List);
-				// Line ++;
 				continue;
 			}
 			NewHertz = g_strdup_printf ("<span color=\"forestgreen\"><b>%s</b></span>", info->NewHertz);
@@ -278,7 +261,7 @@ void FileWav_affiche_glist (void)
 			NewBits  = g_strdup_printf ("<span color=\"forestgreen\"><b>%s</b></span>", info->NewBits);
 			
 			NameDest = libutils_get_name_without_ext_with_amp (detail->namefile);
-			
+
 			gtk_list_store_append (var_file_wav.Adr_List_Store, &iter);
 			gtk_list_store_set (var_file_wav.Adr_List_Store, &iter,
 						COLUMN_FILEWAV_HERTZ,		info->hertz,
@@ -299,26 +282,26 @@ void FileWav_affiche_glist (void)
 			
 			// AFFICHE LES EVENTUELLES LIGNES EN SELECTION
 			// 
-			if (NULL != TabInt) {
-				if (Line == *(TabInt + Cpt)) {
-					gtk_tree_selection_select_iter (var_file_wav.Adr_Line_Selected, &iter);
-					Cpt ++;
-				}
-				Line ++;
+			if( NumLineSelected == Line ) {
+				gtk_tree_selection_select_iter (var_file_wav.Adr_Line_Selected, &iter);
+				BoolNumLineSelected = TRUE;
 			}
+			
+			Line ++;
 		}
 		List = g_list_next (List);
 	}
 	
 	// SUPPRESSON TABLEAU DES EVENTUELLES LIGNES EN SELECTION
 	// 
-	if (NULL != TabInt) {
-		g_free (TabInt);
-		TabInt = NULL;
-	}
-	else {
-		if (gtk_tree_model_get_iter_first (var_file_wav.Adr_Tree_Model, &iter))
+	if( NumLineSelected == -1 ) {
+		if (gtk_tree_model_get_iter_first (var_file_wav.Adr_Tree_Model, &iter)) {
 			gtk_tree_selection_select_iter (var_file_wav.Adr_Line_Selected, &iter);
+			BoolNumLineSelected = TRUE;
+		}
+	}
+	if( NumLineSelected > 0 && NULL != entetefile && BoolNumLineSelected == FALSE ) {
+		gtk_tree_selection_select_iter (var_file_wav.Adr_Line_Selected, &iter);
 	}
 
 	// REAJUSTEMENT DE LA LISTE
