@@ -85,6 +85,7 @@ static void filewavconv_thread (void *arg)
 	INFO_WAV	*info = NULL;
 	gint		pos;
 	CONV_FIC_WAV	*PConvWav = NULL;
+	gchar		**PtrTabArgs = NULL;
 
 	// PRINT_FUNC_LF();
 
@@ -133,24 +134,25 @@ static void filewavconv_thread (void *arg)
 				
 				PConvWav = detail->PConvWav;
 				
-				pos = filelc_get_command_line_nice ();
-				conv.ArgConv [ pos++ ] = g_strdup ("mplayer");
-				conv.ArgConv [ pos++ ] = g_strdup ("-nojoystick");
-				conv.ArgConv [ pos++ ] = g_strdup ("-nolirc");
-				conv.ArgConv [ pos++ ] = g_strdup (PConvWav->TmpSrc);
-				conv.ArgConv [ pos++ ] = g_strdup ("-ao");
-				conv.ArgConv [ pos++ ] = g_strdup ("pcm");
-				conv.ArgConv [ pos++ ] = g_strdup ("-ao");
-				conv.ArgConv [ pos++ ] = g_strdup_printf ("pcm:file=%s", PConvWav->TmpMplayer);
-				conv.ArgConv [ pos++ ] = g_strdup ("-af");
-				conv.ArgConv [ pos++ ] = g_strdup_printf ("channels=%s", info->NewVoie);
-				conv.ArgConv [ pos++ ] = g_strdup ("-srate");
-				conv.ArgConv [ pos++ ] = g_strdup (info->NewHertz);
-				conv.ArgConv [ pos++ ] = NULL;
+				PtrTabArgs = filelc_AllocTabArgs();
+				pos = 3;
+				PtrTabArgs [ pos++ ] = g_strdup ("mplayer");
+				PtrTabArgs [ pos++ ] = g_strdup ("-nojoystick");
+				PtrTabArgs [ pos++ ] = g_strdup ("-nolirc");
+				PtrTabArgs [ pos++ ] = g_strdup (PConvWav->TmpSrc);
+				PtrTabArgs [ pos++ ] = g_strdup ("-ao");
+				PtrTabArgs [ pos++ ] = g_strdup ("pcm");
+				PtrTabArgs [ pos++ ] = g_strdup ("-ao");
+				PtrTabArgs [ pos++ ] = g_strdup_printf ("pcm:file=%s", PConvWav->TmpMplayer);
+				PtrTabArgs [ pos++ ] = g_strdup ("-af");
+				PtrTabArgs [ pos++ ] = g_strdup_printf ("channels=%s", info->NewVoie);
+				PtrTabArgs [ pos++ ] = g_strdup ("-srate");
+				PtrTabArgs [ pos++ ] = g_strdup (info->NewHertz);
+				PtrTabArgs [ pos++ ] = NULL;
 				
 				VarFilewavconv.BoolMplayer = TRUE;
-				conv_to_convert (FALSE, MPLAYER_WAV_TO_WAV, "MPLAYER_WAV_TO_WAV");
-				filelc_get_command_line_remove ();
+				conv_to_convert( PtrTabArgs, FALSE, MPLAYER_WAV_TO_WAV, "MPLAYER_WAV_TO_WAV");
+				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 				VarFilewavconv.BoolMplayer = FALSE;
 
 				VarFilewavconv.BoolCopy = TRUE;
@@ -160,9 +162,9 @@ static void filewavconv_thread (void *arg)
 				if (atoi (info->bits) != atoi (info->NewBits)) {
 					
 					VarFilewavconv.BoolSox = TRUE;
-					conv_with_sox_get_param (PConvWav->TmpSrc, PConvWav->TmpDest, info->NewHertz, info->NewVoie, info->NewBits);
-					conv_to_convert (FALSE, SOX_WAV_TO_WAV, "SOX_WAV_TO_WAV");
-					filelc_get_command_line_remove ();
+					PtrTabArgs = conv_with_sox_get_param (PConvWav->TmpSrc, PConvWav->TmpDest, info->NewHertz, info->NewVoie, info->NewBits);
+					conv_to_convert( PtrTabArgs, FALSE, SOX_WAV_TO_WAV, "SOX_WAV_TO_WAV");
+					PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 					
 					VarFilewavconv.BoolSox = FALSE;
 					VarFilewavconv.BoolCopy = TRUE;
