@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2012 by Claude Bulin
+ *  copyright : (C) 2003 - 2013 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -399,6 +399,8 @@ void fileselect_create (TYPE_FILESELECTION Choice, gchar *Path, void *Func_Exter
 			filter = gtk_file_filter_new ();
 			gtk_file_filter_add_pattern (filter, "*.wav");
 			gtk_file_filter_add_pattern (filter, "*.WAV");
+			gtk_file_filter_add_pattern (filter, "*.bwf");
+			gtk_file_filter_add_pattern (filter, "*.BWF");
 			gtk_file_filter_add_pattern (filter, "*.flac");
 			gtk_file_filter_add_pattern (filter, "*.FLAC");
 			gtk_file_filter_add_pattern (filter, "*.ogg");
@@ -422,6 +424,12 @@ void fileselect_create (TYPE_FILESELECTION Choice, gchar *Path, void *Func_Exter
 			gtk_file_filter_add_pattern (filter, "*.WAV");
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
 			
+			filter = gtk_file_filter_new ();
+			gtk_file_filter_set_name (filter, "BWF (*.bwf)");
+			gtk_file_filter_add_pattern (filter, "*.bwf");
+			gtk_file_filter_add_pattern (filter, "*.BWF");
+			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
+			
 			filter = gtk_file_filter_new ();
 			gtk_file_filter_set_name (filter, "FLAC (*.flac)");
 			gtk_file_filter_add_pattern (filter, "*.flac");
@@ -464,6 +472,8 @@ void fileselect_create (TYPE_FILESELECTION Choice, gchar *Path, void *Func_Exter
 			gtk_file_filter_set_name (filter, _("All Files (*.*)"));
 			gtk_file_filter_add_pattern (filter, "*.wav");
 			gtk_file_filter_add_pattern (filter, "*.WAV");
+			gtk_file_filter_add_pattern (filter, "*.bwf");
+			gtk_file_filter_add_pattern (filter, "*.BWF");
 			gtk_file_filter_add_pattern (filter, "*.flac");
 			gtk_file_filter_add_pattern (filter, "*.FLAC");
 			gtk_file_filter_add_pattern (filter, "*.ape");
@@ -505,6 +515,11 @@ void fileselect_create (TYPE_FILESELECTION Choice, gchar *Path, void *Func_Exter
 			gtk_file_filter_add_pattern (filter, "*.WAV");
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
 			filter = gtk_file_filter_new ();
+			gtk_file_filter_set_name (filter, "BWF (*.bwf)");
+			gtk_file_filter_add_pattern (filter, "*.bwf");
+			gtk_file_filter_add_pattern (filter, "*.BWF");
+			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
+			filter = gtk_file_filter_new ();
 			gtk_file_filter_set_name (filter, "FLAC (*.flac)");
 			gtk_file_filter_add_pattern (filter, "*.flac");
 			gtk_file_filter_add_pattern (filter, "*.FLAC");
@@ -580,7 +595,9 @@ void fileselect_create (TYPE_FILESELECTION Choice, gchar *Path, void *Func_Exter
 			gtk_file_filter_set_name (filter, _("All Files (*.*)"));
 			gtk_file_filter_add_pattern (filter, "*.wav");
 			gtk_file_filter_add_pattern (filter, "*.WAV");
-			gtk_file_filter_set_name (filter, "*.wav");
+			gtk_file_filter_add_pattern (filter, "*.bwf");
+			gtk_file_filter_add_pattern (filter, "*.BWF");
+			gtk_file_filter_set_name (filter, "*.wav *.bwf");
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
 		}
 		else if (Choice == _PATH_LOAD_FILE_MP3OGG_) {
