@@ -527,7 +527,7 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	GList	*GListFile = NULL;
 
 	/* Init type system as soon as possible */
-	g_type_init ();
+	// g_type_init ();
 	g_set_prgname ("xcfa");
 	
 	PRINT_FUNC_LF();
@@ -639,14 +639,16 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	// PathShareProjet = g_strdup_printf ("%s/%s/glade/%s", DATA_DIR, PACKAGE_NAME, PACKAGE_NAME_GLADE);
 	PathShareProjet = xdg_search_data_xdg( PACKAGE_NAME_GLADE );
 
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		g_print("\n");
+		g_print("!---\n");
+		g_print("! File XML: [ %s ] %s\n", PathCurrentDir != NULL ? PathCurrentDir : PACKAGE_NAME_GLADE, g_file_test (PathCurrentDir, G_FILE_TEST_EXISTS) ? "Found" : "Not Found !!!" );
+		g_print("!---\n");
+		g_print("! File XML: [ %s ] %s\n", PathShareProjet != NULL ? PathShareProjet : PACKAGE_NAME_GLADE, g_file_test (PathShareProjet, G_FILE_TEST_EXISTS) ? "Found" : "Not Found !!!" );
+		g_print("!---\n");
+	}
+	
 	if (FALSE == g_file_test (PathCurrentDir, G_FILE_TEST_EXISTS) && FALSE == g_file_test (PathShareProjet, G_FILE_TEST_EXISTS)) {
-		if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
-			g_print("!---------------------------------------------------------------------------------------------------\n");
-			g_print("! LE FICHIER XML: [ %s ] N'EXISTE PAS !!!\n", PathCurrentDir);
-			g_print("!---------------------------------------------------------------------------------------------------\n");
-			g_print("! LE FICHIER XML: [ %s ] N'EXISTE PAS !!!\n", PathShareProjet);
-			g_print("!---------------------------------------------------------------------------------------------------\n");
-		}
 		g_free (PathCurrentDir);
 		PathCurrentDir = NULL;
 		g_free (PathShareProjet);
