@@ -259,6 +259,7 @@ void normalise_FIX_wav (void)
 	GList		*List = NULL;
 	INDI_FIX	*IndiFix = NULL;
 	gint		pos;
+	gchar		**PtrTabArgs = NULL;
 
 	List = g_list_first (normalise.ListFixWav);
 	while (FALSE == normalise.bool_set_end_of_user && List) {
@@ -272,17 +273,18 @@ void normalise_FIX_wav (void)
 
 			// Normalisation du Wav
 			// 
-			pos = filelc_get_command_line_nice ();
-			conv.ArgConv [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
-			conv.ArgConv [ pos++ ] = g_strdup ("-a");
-			conv.ArgConv [ pos++ ] = g_strdup_printf ("%s,0000dB", IndiFix->StrDBFS);
-			conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
-			conv.ArgConv [ pos++ ] = NULL;
+			PtrTabArgs = filelc_AllocTabArgs();
+			pos = 3;
+			PtrTabArgs [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
+			PtrTabArgs [ pos++ ] = g_strdup ("-a");
+			PtrTabArgs [ pos++ ] = g_strdup_printf ("%s,0000dB", IndiFix->StrDBFS);
+			PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
+			PtrTabArgs [ pos++ ] = NULL;
 
 			normalise_set_mess ("Normalise Wav -> Fix");
 
-			conv_to_convert (FALSE, NORMALISE_EXEC, "NORMALISE_EXEC Wav -> Fix");
-			filelc_get_command_line_remove ();
+			conv_to_convert( PtrTabArgs, FALSE, NORMALISE_EXEC, "NORMALISE_EXEC Wav -> Fix");
+			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 			
 			normalise.ElementActif ++;
 
@@ -317,6 +319,7 @@ void normalise_FIX_ogg (void)
 	INDI_FIX	*IndiFix = NULL;
 	PARAM_FILELC	 param_filelc;
 	gint		 pos;
+	gchar		**PtrTabArgs = NULL;
 
 	List = g_list_first (normalise.ListFixOgg);
 	while (FALSE == normalise.bool_set_end_of_user && List) {
@@ -327,20 +330,21 @@ void normalise_FIX_ogg (void)
 
 			normalise_set_mess ("Conversion Ogg vers Wav");
 
-			pos = filelc_get_command_line_nice ();
-			conv.ArgConv [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
-			conv.ArgConv [ pos++ ] = g_strdup ("mplayer");
-			conv.ArgConv [ pos++ ] = g_strdup ("-nojoystick");
-			conv.ArgConv [ pos++ ] = g_strdup ("-nolirc");
-			conv.ArgConv [ pos++ ] = g_strdup ("-ao");
-			conv.ArgConv [ pos++ ] = g_strdup ("pcm");
-			conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFile);
-			conv.ArgConv [ pos++ ] = g_strdup ("-ao");
-			conv.ArgConv [ pos++ ] = g_strdup_printf ("pcm:file=%s", IndiFix->NameFileCopieWav);
-			conv.ArgConv [ pos++ ] = NULL;
+			PtrTabArgs = filelc_AllocTabArgs();
+			pos = 3;
+			PtrTabArgs [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
+			PtrTabArgs [ pos++ ] = g_strdup ("mplayer");
+			PtrTabArgs [ pos++ ] = g_strdup ("-nojoystick");
+			PtrTabArgs [ pos++ ] = g_strdup ("-nolirc");
+			PtrTabArgs [ pos++ ] = g_strdup ("-ao");
+			PtrTabArgs [ pos++ ] = g_strdup ("pcm");
+			PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFile);
+			PtrTabArgs [ pos++ ] = g_strdup ("-ao");
+			PtrTabArgs [ pos++ ] = g_strdup_printf ("pcm:file=%s", IndiFix->NameFileCopieWav);
+			PtrTabArgs [ pos++ ] = NULL;
 
-			conv_to_convert (FALSE, MPLAYER_OGG_TO_WAV, "MPLAYER_OGG_TO_WAV");
-			filelc_get_command_line_remove ();
+			conv_to_convert( PtrTabArgs, FALSE, MPLAYER_OGG_TO_WAV, "MPLAYER_OGG_TO_WAV");
+			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 			
 			normalise.ElementActif ++;
 
@@ -349,15 +353,16 @@ void normalise_FIX_ogg (void)
 
 			normalise_set_mess ("Normalise Wav -> Fix");
 
-			pos = filelc_get_command_line_nice ();
-			conv.ArgConv [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
-			conv.ArgConv [ pos++ ] = g_strdup ("-a");
-			conv.ArgConv [ pos++ ] = g_strdup_printf ("%s,0000dB", IndiFix->StrDBFS);
-			conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
-			conv.ArgConv [ pos++ ] = NULL;
+			PtrTabArgs = filelc_AllocTabArgs();
+			pos = 3;
+			PtrTabArgs [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
+			PtrTabArgs [ pos++ ] = g_strdup ("-a");
+			PtrTabArgs [ pos++ ] = g_strdup_printf ("%s,0000dB", IndiFix->StrDBFS);
+			PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
+			PtrTabArgs [ pos++ ] = NULL;
 			
-			conv_to_convert (FALSE, NORMALISE_EXEC, "NORMALISE_EXEC NORMALISATION du Wav");
-			filelc_get_command_line_remove ();
+			conv_to_convert( PtrTabArgs, FALSE, NORMALISE_EXEC, "NORMALISE_EXEC NORMALISATION du Wav");
+			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 
 			normalise.ElementActif ++;
 
@@ -381,9 +386,9 @@ void normalise_FIX_ogg (void)
 				param_filelc.num_track             = NULL;
 				param_filelc.PtrStrBitrate         = NULL;
 
-				filelc_get_command_line (&param_filelc);
-				conv_to_convert (FALSE, OGGENC_WAV_TO_OGG, "OGGENC_WAV_TO_OGG");
-				filelc_get_command_line_remove ();
+				PtrTabArgs = filelc_get_command_line (&param_filelc);
+				conv_to_convert( PtrTabArgs, FALSE, OGGENC_WAV_TO_OGG, "OGGENC_WAV_TO_OGG");
+				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 
 				g_unlink (IndiFix->NameFileCopieWav);
 								
@@ -403,6 +408,7 @@ void normalise_FIX_mp3 (void)
 	INDI_FIX	*IndiFix = NULL;
 	PARAM_FILELC	param_filelc;
 	gint		pos;
+	gchar		**PtrTabArgs = NULL;
 
 	List = g_list_first (normalise.ListFixMp3);
 	while (FALSE == normalise.bool_set_end_of_user && List) {
@@ -412,25 +418,25 @@ void normalise_FIX_mp3 (void)
 
 			normalise_set_mess ("Conversion Mp3 vers Wav");
 
-			pos = filelc_get_command_line_nice ();
-			conv.ArgConv [ pos++ ] = g_strdup ("mplayer");
-			conv.ArgConv [ pos++ ] = g_strdup ("-nojoystick");
-			conv.ArgConv [ pos++ ] = g_strdup ("-nolirc");
-			conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFile);
-			conv.ArgConv [ pos++ ] = g_strdup ("-ao");
-			conv.ArgConv [ pos++ ] = g_strdup ("pcm");
-			conv.ArgConv [ pos++ ] = g_strdup ("-ao");
-			conv.ArgConv [ pos++ ] = g_strdup_printf ("pcm:file=%s",IndiFix->NameFileCopieWav);
-			conv.ArgConv [ pos++ ] = g_strdup ("-af");
-			conv.ArgConv [ pos++ ] = g_strdup ("channels=2");
-			conv.ArgConv [ pos++ ] = g_strdup ("-srate");
-			conv.ArgConv [ pos++ ] = g_strdup ("44100");
-			conv.ArgConv [ pos++ ] = NULL;
+			PtrTabArgs = filelc_AllocTabArgs();
+			pos = 3;
+			PtrTabArgs [ pos++ ] = g_strdup ("mplayer");
+			PtrTabArgs [ pos++ ] = g_strdup ("-nojoystick");
+			PtrTabArgs [ pos++ ] = g_strdup ("-nolirc");
+			PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFile);
+			PtrTabArgs [ pos++ ] = g_strdup ("-ao");
+			PtrTabArgs [ pos++ ] = g_strdup ("pcm");
+			PtrTabArgs [ pos++ ] = g_strdup ("-ao");
+			PtrTabArgs [ pos++ ] = g_strdup_printf ("pcm:file=%s",IndiFix->NameFileCopieWav);
+			PtrTabArgs [ pos++ ] = g_strdup ("-af");
+			PtrTabArgs [ pos++ ] = g_strdup ("channels=2");
+			PtrTabArgs [ pos++ ] = g_strdup ("-srate");
+			PtrTabArgs [ pos++ ] = g_strdup ("44100");
+			PtrTabArgs [ pos++ ] = NULL;
 			
-			conv_to_convert (FALSE, MPLAYER_MP3_TO_WAV, "MPLAYER_MP3_TO_WAV");
-			filelc_get_command_line_remove ();
+			conv_to_convert( PtrTabArgs, FALSE, MPLAYER_MP3_TO_WAV, "MPLAYER_MP3_TO_WAV");
+			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 
-			
 			normalise.ElementActif ++;
 
 			/* Normalisation du Wav
@@ -438,15 +444,16 @@ void normalise_FIX_mp3 (void)
 
 			normalise_set_mess ("Normalise Wav -> Fix");
 
-			pos = filelc_get_command_line_nice ();
-			conv.ArgConv [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
-			conv.ArgConv [ pos++ ] = g_strdup ("-a");
-			conv.ArgConv [ pos++ ] = g_strdup_printf ("%s,0000dB", IndiFix->StrDBFS);
-			conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
-			conv.ArgConv [ pos++ ] = NULL;
+			PtrTabArgs = filelc_AllocTabArgs();
+			pos = 3;
+			PtrTabArgs [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
+			PtrTabArgs [ pos++ ] = g_strdup ("-a");
+			PtrTabArgs [ pos++ ] = g_strdup_printf ("%s,0000dB", IndiFix->StrDBFS);
+			PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
+			PtrTabArgs [ pos++ ] = NULL;
 			
-			conv_to_convert (FALSE, NORMALISE_EXEC, "NORMALISE_EXEC NORMALISATION du Wav");
-			filelc_get_command_line_remove ();
+			conv_to_convert( PtrTabArgs, FALSE, NORMALISE_EXEC, "NORMALISE_EXEC NORMALISATION du Wav");
+			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 			
 			normalise.ElementActif ++;
 
@@ -470,9 +477,9 @@ void normalise_FIX_mp3 (void)
 				param_filelc.num_track            = NULL;
 				param_filelc.PtrStrBitrate        = NULL;
 
-				filelc_get_command_line (&param_filelc);
-				conv_to_convert (FALSE, LAME_WAV_TO_MP3, "LAME_WAV_TO_MP3");
-				filelc_get_command_line_remove ();
+				PtrTabArgs = filelc_get_command_line (&param_filelc);
+				conv_to_convert( PtrTabArgs, FALSE, LAME_WAV_TO_MP3, "LAME_WAV_TO_MP3");
+				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 				
 				g_unlink (IndiFix->NameFileCopieWav);
 				
@@ -492,6 +499,7 @@ void normalise_PEAK_wav (void)
 	GList		*List = NULL;
 	INDI_FIX	*IndiFix = NULL;
 	gint		pos;
+	gchar		**PtrTabArgs = NULL;
 	
 	List = g_list_first (normalise.ListPeakWav);
 	while (FALSE == normalise.bool_set_end_of_user && List) {
@@ -511,17 +519,18 @@ void normalise_PEAK_wav (void)
 
 			normalise_set_mess ("Normalise Wav -> Peak");
 
-			pos = filelc_get_command_line_nice ();
-			conv.ArgConv [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
-			conv.ArgConv [ pos++ ] = g_strdup ("--peak");
-			conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
-			conv.ArgConv [ pos++ ] = g_strdup ("--");
-			conv.ArgConv [ pos++ ] = NULL;
+			PtrTabArgs = filelc_AllocTabArgs();
+			pos = 3;
+			PtrTabArgs [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
+			PtrTabArgs [ pos++ ] = g_strdup ("--peak");
+			PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
+			PtrTabArgs [ pos++ ] = g_strdup ("--");
+			PtrTabArgs [ pos++ ] = NULL;
 
 			if (*IndiFix->EtatTrash == FILE_TRASH_OK) *IndiFix->EtatTrash = FILE_TRASH_VERIF_OK;
 
-			conv_to_convert (FALSE, NORMALISE_EXEC, "NORMALISE_EXEC Wav -> Peak");
-			filelc_get_command_line_remove ();
+			conv_to_convert( PtrTabArgs, FALSE, NORMALISE_EXEC, "NORMALISE_EXEC Wav -> Peak");
+			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 			
 			normalise.ElementActif ++;
 
@@ -554,6 +563,7 @@ void normalise_PEAK_ogg (void)
 	INDI_FIX	*IndiFix = NULL;
 	PARAM_FILELC	param_filelc;
 	gint		pos;
+	gchar		**PtrTabArgs = NULL;
 
 	List = g_list_first (normalise.ListPeakOgg);
 	while (FALSE == normalise.bool_set_end_of_user && List) {
@@ -563,17 +573,18 @@ void normalise_PEAK_ogg (void)
 			*/
 			normalise_set_mess ("Conversion Ogg vers Wav");
 
-			pos = filelc_get_command_line_nice ();
-			conv.ArgConv [ pos++ ] = g_strdup ("ogg123");
-			conv.ArgConv [ pos++ ] = g_strdup ("-d");
-			conv.ArgConv [ pos++ ] = g_strdup ("wav");
-			conv.ArgConv [ pos++ ] = g_strdup ("-f");
-			conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
-			conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFile);
-			conv.ArgConv [ pos++ ] = NULL;
+			PtrTabArgs = filelc_AllocTabArgs();
+			pos = 3;
+			PtrTabArgs [ pos++ ] = g_strdup ("ogg123");
+			PtrTabArgs [ pos++ ] = g_strdup ("-d");
+			PtrTabArgs [ pos++ ] = g_strdup ("wav");
+			PtrTabArgs [ pos++ ] = g_strdup ("-f");
+			PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
+			PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFile);
+			PtrTabArgs [ pos++ ] = NULL;
 
-			conv_to_convert (FALSE, OGG123_OGG_TO_WAV, "OGG123_OGG_TO_WAV CONVERSION Ogg vers Wav");
-			filelc_get_command_line_remove ();
+			conv_to_convert( PtrTabArgs, FALSE, OGG123_OGG_TO_WAV, "OGG123_OGG_TO_WAV CONVERSION Ogg vers Wav");
+			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 
 			normalise.ElementActif ++;
 		
@@ -581,16 +592,17 @@ void normalise_PEAK_ogg (void)
 			*/
 			normalise_set_mess ("Normalise Wav -> Fix");
 
-			pos = filelc_get_command_line_nice ();
-			conv.ArgConv [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
-			conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
-			conv.ArgConv [ pos++ ] = g_strdup ("--peak");
-			conv.ArgConv [ pos++ ] = NULL;
+			PtrTabArgs = filelc_AllocTabArgs();
+			pos = 3;
+			PtrTabArgs [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
+			PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
+			PtrTabArgs [ pos++ ] = g_strdup ("--peak");
+			PtrTabArgs [ pos++ ] = NULL;
 			
 			if (*IndiFix->EtatTrash == FILE_TRASH_OK) *IndiFix->EtatTrash = FILE_TRASH_VERIF_OK;
 
-			conv_to_convert (FALSE, NORMALISE_EXEC, "NORMALISE_EXEC Wav -> Peak");
-			filelc_get_command_line_remove ();
+			conv_to_convert( PtrTabArgs, FALSE, NORMALISE_EXEC, "NORMALISE_EXEC Wav -> Peak");
+			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 
 			normalise.ElementActif ++;
 		
@@ -614,9 +626,9 @@ void normalise_PEAK_ogg (void)
 				param_filelc.num_track             = NULL;
 				param_filelc.PtrStrBitrate         = NULL;
 
-				filelc_get_command_line (&param_filelc);
-				conv_to_convert (FALSE, OGGENC_WAV_TO_OGG, "OGGENC_WAV_TO_OGG");
-				filelc_get_command_line_remove ();
+				PtrTabArgs = filelc_get_command_line (&param_filelc);
+				conv_to_convert( PtrTabArgs, FALSE, OGGENC_WAV_TO_OGG, "OGGENC_WAV_TO_OGG");
+				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 				
 				g_unlink (IndiFix->NameFileCopieWav);
 				
@@ -635,6 +647,7 @@ void normalise_PEAK_mp3 (void)
 	INDI_FIX	*IndiFix = NULL;
 	PARAM_FILELC	param_filelc;
 	gint		pos;
+	gchar		**PtrTabArgs = NULL;
 
 	List = g_list_first (normalise.ListPeakMp3);
 	while (FALSE == normalise.bool_set_end_of_user && List) {
@@ -644,23 +657,24 @@ void normalise_PEAK_mp3 (void)
 			*/
 			normalise_set_mess ("Conversion Mp3 vers Wav");
 
-			pos = filelc_get_command_line_nice ();
-			conv.ArgConv [ pos++ ] = g_strdup ("mplayer");
-			conv.ArgConv [ pos++ ] = g_strdup ("-nojoystick");
-			conv.ArgConv [ pos++ ] = g_strdup ("-nolirc");
-			conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFile);
-			conv.ArgConv [ pos++ ] = g_strdup ("-ao");
-			conv.ArgConv [ pos++ ] = g_strdup ("pcm");
-			conv.ArgConv [ pos++ ] = g_strdup ("-ao");
-			conv.ArgConv [ pos++ ] = g_strdup_printf ("pcm:file=%s",IndiFix->NameFileCopieWav);
-			conv.ArgConv [ pos++ ] = g_strdup ("-af");
-			conv.ArgConv [ pos++ ] = g_strdup ("channels=2");
-			conv.ArgConv [ pos++ ] = g_strdup ("-srate");
-			conv.ArgConv [ pos++ ] = g_strdup ("44100");
-			conv.ArgConv [ pos++ ] = NULL;
+			PtrTabArgs = filelc_AllocTabArgs();
+			pos = 3;
+			PtrTabArgs [ pos++ ] = g_strdup ("mplayer");
+			PtrTabArgs [ pos++ ] = g_strdup ("-nojoystick");
+			PtrTabArgs [ pos++ ] = g_strdup ("-nolirc");
+			PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFile);
+			PtrTabArgs [ pos++ ] = g_strdup ("-ao");
+			PtrTabArgs [ pos++ ] = g_strdup ("pcm");
+			PtrTabArgs [ pos++ ] = g_strdup ("-ao");
+			PtrTabArgs [ pos++ ] = g_strdup_printf ("pcm:file=%s",IndiFix->NameFileCopieWav);
+			PtrTabArgs [ pos++ ] = g_strdup ("-af");
+			PtrTabArgs [ pos++ ] = g_strdup ("channels=2");
+			PtrTabArgs [ pos++ ] = g_strdup ("-srate");
+			PtrTabArgs [ pos++ ] = g_strdup ("44100");
+			PtrTabArgs [ pos++ ] = NULL;
 			
-			conv_to_convert (FALSE, MPLAYER_MP3_TO_WAV, "MPLAYER_MP3_TO_WAV");
-			filelc_get_command_line_remove ();
+			conv_to_convert( PtrTabArgs, FALSE, MPLAYER_MP3_TO_WAV, "MPLAYER_MP3_TO_WAV");
+			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 			
 			normalise.ElementActif ++;
 
@@ -668,14 +682,15 @@ void normalise_PEAK_mp3 (void)
 			*/
 			normalise_set_mess ("Normalise Wav -> Peak");
 
-			pos = filelc_get_command_line_nice ();
-			conv.ArgConv [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
-			conv.ArgConv [ pos++ ] = g_strdup ("--peak");
-			conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFileCopieMp3);
-			conv.ArgConv [ pos++ ] = NULL;
+			PtrTabArgs = filelc_AllocTabArgs();
+			pos = 3;
+			PtrTabArgs [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
+			PtrTabArgs [ pos++ ] = g_strdup ("--peak");
+			PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFileCopieMp3);
+			PtrTabArgs [ pos++ ] = NULL;
 			
-			conv_to_convert (FALSE, NORMALISE_EXEC, "NORMALISE_EXEC Wav -> Peak");
-			filelc_get_command_line_remove ();
+			conv_to_convert( PtrTabArgs, FALSE, NORMALISE_EXEC, "NORMALISE_EXEC Wav -> Peak");
+			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 
 			normalise.ElementActif ++;
 
@@ -699,9 +714,9 @@ void normalise_PEAK_mp3 (void)
 				param_filelc.num_track            = NULL;
 				param_filelc.PtrStrBitrate        = NULL;
 
-				filelc_get_command_line (&param_filelc);
-				conv_to_convert (FALSE, LAME_WAV_TO_MP3, "LAME_WAV_TO_MP3");
-				filelc_get_command_line_remove ();
+				PtrTabArgs = filelc_get_command_line (&param_filelc);
+				conv_to_convert( PtrTabArgs, FALSE, LAME_WAV_TO_MP3, "LAME_WAV_TO_MP3");
+				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 				
 				g_unlink (IndiFix->NameFileCopieWav);
 								
@@ -722,6 +737,7 @@ void normalise_MIX_RMS_GROUP_wav_ogg_mp3 (void)
 	INDI_FIX	*IndiFix = NULL;
 	PARAM_FILELC	param_filelc;
 	gint		pos;
+	gchar		**PtrTabArgs = NULL;
 
 	PRINT_FUNC_LF();
 
@@ -743,17 +759,18 @@ void normalise_MIX_RMS_GROUP_wav_ogg_mp3 (void)
 		while (List) {
 			if ((IndiFix = (INDI_FIX *)List->data)) {
 				
-				pos = filelc_get_command_line_nice ();
-				conv.ArgConv [ pos++ ] = g_strdup ("ogg123");
-				conv.ArgConv [ pos++ ] = g_strdup ("-d");
-				conv.ArgConv [ pos++ ] = g_strdup ("wav");
-				conv.ArgConv [ pos++ ] = g_strdup ("-f");
-				conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
-				conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFile);
-				conv.ArgConv [ pos++ ] = NULL;
+				PtrTabArgs = filelc_AllocTabArgs();
+				pos = 3;
+				PtrTabArgs [ pos++ ] = g_strdup ("ogg123");
+				PtrTabArgs [ pos++ ] = g_strdup ("-d");
+				PtrTabArgs [ pos++ ] = g_strdup ("wav");
+				PtrTabArgs [ pos++ ] = g_strdup ("-f");
+				PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
+				PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFile);
+				PtrTabArgs [ pos++ ] = NULL;
 
-				conv_to_convert (FALSE, OGG123_OGG_TO_WAV, "OGG123_OGG_TO_WAV CONVERSION Ogg vers Wav");
-				filelc_get_command_line_remove ();
+				conv_to_convert( PtrTabArgs, FALSE, OGG123_OGG_TO_WAV, "OGG123_OGG_TO_WAV CONVERSION Ogg vers Wav");
+				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 
 				normalise.ElementActif ++;
 			}
@@ -769,24 +786,25 @@ void normalise_MIX_RMS_GROUP_wav_ogg_mp3 (void)
 		while (List) {
 			if ((IndiFix = (INDI_FIX *)List->data)) {
 				
-				pos = filelc_get_command_line_nice ();
-				conv.ArgConv [ pos++ ] = g_strdup ("mplayer");
-				conv.ArgConv [ pos++ ] = g_strdup ("-nojoystick");
-				conv.ArgConv [ pos++ ] = g_strdup ("-nolirc");
-				conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFile);
-				conv.ArgConv [ pos++ ] = g_strdup ("-ao");
-				conv.ArgConv [ pos++ ] = g_strdup ("pcm");
-				conv.ArgConv [ pos++ ] = g_strdup ("-ao");
-				conv.ArgConv [ pos++ ] = g_strdup_printf ("pcm:file=%s",IndiFix->NameFileCopieWav);
-				conv.ArgConv [ pos++ ] = g_strdup ("-af");
-				conv.ArgConv [ pos++ ] = g_strdup ("channels=2");
-				conv.ArgConv [ pos++ ] = g_strdup ("-srate");
-				conv.ArgConv [ pos++ ] = g_strdup ("44100");
-				conv.ArgConv [ pos++ ] = NULL;
+				PtrTabArgs = filelc_AllocTabArgs();
+				pos = 3;
+				PtrTabArgs [ pos++ ] = g_strdup ("mplayer");
+				PtrTabArgs [ pos++ ] = g_strdup ("-nojoystick");
+				PtrTabArgs [ pos++ ] = g_strdup ("-nolirc");
+				PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFile);
+				PtrTabArgs [ pos++ ] = g_strdup ("-ao");
+				PtrTabArgs [ pos++ ] = g_strdup ("pcm");
+				PtrTabArgs [ pos++ ] = g_strdup ("-ao");
+				PtrTabArgs [ pos++ ] = g_strdup_printf ("pcm:file=%s",IndiFix->NameFileCopieWav);
+				PtrTabArgs [ pos++ ] = g_strdup ("-af");
+				PtrTabArgs [ pos++ ] = g_strdup ("channels=2");
+				PtrTabArgs [ pos++ ] = g_strdup ("-srate");
+				PtrTabArgs [ pos++ ] = g_strdup ("44100");
+				PtrTabArgs [ pos++ ] = NULL;
+
+				conv_to_convert( PtrTabArgs, FALSE, MPLAYER_MP3_TO_WAV, "MPLAYER_MP3_TO_WAV");
+				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 
-				conv_to_convert (FALSE, MPLAYER_MP3_TO_WAV, "MPLAYER_MP3_TO_WAV");
-				filelc_get_command_line_remove ();
-				
 				normalise.ElementActif ++;
 			}
 			List = g_list_next(List);
@@ -799,16 +817,17 @@ void normalise_MIX_RMS_GROUP_wav_ogg_mp3 (void)
 
 		normalise_set_mess ("(MIX)RMS/GROUPE: Normalise Wav");
 		
-		pos = filelc_get_command_line_nice ();
-		conv.ArgConv [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
-		conv.ArgConv [ pos++ ] = g_strdup ("-a");
-		conv.ArgConv [ pos++ ] = g_strdup_printf ("%d,0000dB", normalise.LevelMix);
-		conv.ArgConv [ pos++ ] = g_strdup ("--batch");
+		PtrTabArgs = filelc_AllocTabArgs();
+		pos = 3;
+		PtrTabArgs [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
+		PtrTabArgs [ pos++ ] = g_strdup ("-a");
+		PtrTabArgs [ pos++ ] = g_strdup_printf ("%d,0000dB", normalise.LevelMix);
+		PtrTabArgs [ pos++ ] = g_strdup ("--batch");
 		/* Creation liste WAV */
 		List = g_list_first (normalise.ListMixGroupWav);
 		while (List) {
 			if (NULL != (IndiFix = (INDI_FIX *)List->data)) {
-				conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
+				PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
 				if (*IndiFix->EtatTrash == FILE_TRASH_OK) *IndiFix->EtatTrash = FILE_TRASH_VERIF_OK;
 			}
 			List = g_list_next(List);
@@ -817,7 +836,7 @@ void normalise_MIX_RMS_GROUP_wav_ogg_mp3 (void)
 		List = g_list_first (normalise.ListMixGroupOgg);
 		while (List) {
 			if (NULL != (IndiFix = (INDI_FIX *)List->data)) {
-				conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
+				PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
 				if (*IndiFix->EtatTrash == FILE_TRASH_OK) *IndiFix->EtatTrash = FILE_TRASH_VERIF_OK;
 			}
 			List = g_list_next(List);
@@ -826,16 +845,16 @@ void normalise_MIX_RMS_GROUP_wav_ogg_mp3 (void)
 		List = g_list_first (normalise.ListMixGroupMp3);
 		while (List) {
 			if (NULL != (IndiFix = (INDI_FIX *)List->data)) {
-				conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
+				PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
 				if (*IndiFix->EtatTrash == FILE_TRASH_OK) *IndiFix->EtatTrash = FILE_TRASH_VERIF_OK;
 			}
 			List = g_list_next(List);
 		}
-		conv.ArgConv [ pos++ ] = NULL;
+		PtrTabArgs [ pos++ ] = NULL;
 		
 		/* Normalisation */
-		conv_to_convert (FALSE, NORMALISE_EXEC, "NORMALISE_EXEC Wav -> (MIX)RMS/GROUPE");
-		filelc_get_command_line_remove ();
+		conv_to_convert( PtrTabArgs, FALSE, NORMALISE_EXEC, "NORMALISE_EXEC Wav -> (MIX)RMS/GROUPE");
+		PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 
 		normalise.ElementActif ++;
 	}
@@ -876,9 +895,9 @@ void normalise_MIX_RMS_GROUP_wav_ogg_mp3 (void)
 					param_filelc.num_track             = NULL;
 					param_filelc.PtrStrBitrate         = NULL;
 
-					filelc_get_command_line (&param_filelc);
-					conv_to_convert (FALSE, OGGENC_WAV_TO_OGG, "OGGENC_WAV_TO_OGG");
-					filelc_get_command_line_remove ();
+					PtrTabArgs = filelc_get_command_line (&param_filelc);
+					conv_to_convert( PtrTabArgs, FALSE, OGGENC_WAV_TO_OGG, "OGGENC_WAV_TO_OGG");
+					PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 				
 					g_unlink (IndiFix->NameFileCopieWav);
 
@@ -904,9 +923,9 @@ void normalise_MIX_RMS_GROUP_wav_ogg_mp3 (void)
 					param_filelc.num_track            = NULL;
 					param_filelc.PtrStrBitrate        = NULL;
 
-					filelc_get_command_line (&param_filelc);
-					conv_to_convert (FALSE, LAME_WAV_TO_MP3, "LAME_WAV_TO_MP3");
-					filelc_get_command_line_remove ();
+					PtrTabArgs = filelc_get_command_line (&param_filelc);
+					conv_to_convert( PtrTabArgs,FALSE, LAME_WAV_TO_MP3, "LAME_WAV_TO_MP3");
+					PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 
 					g_unlink (IndiFix->NameFileCopieWav);
 
@@ -925,6 +944,7 @@ void normalise_PEAK_RMS_GROUP_wav_ogg_mp3 (void)
 	INDI_FIX	*IndiFix = NULL;
 	PARAM_FILELC	param_filelc;
 	gint		pos;
+	gchar		**PtrTabArgs = NULL;
 	
 	/* COPIE  WAV OGG MP3
 	*/
@@ -942,17 +962,19 @@ void normalise_PEAK_RMS_GROUP_wav_ogg_mp3 (void)
 		List = g_list_first (normalise.ListPeakGroupOgg);
 		while (List) {
 			if (NULL != (IndiFix = (INDI_FIX *)List->data)) {
-				pos = filelc_get_command_line_nice ();
-				conv.ArgConv [ pos++ ] = g_strdup ("ogg123");
-				conv.ArgConv [ pos++ ] = g_strdup ("-d");
-				conv.ArgConv [ pos++ ] = g_strdup ("wav");
-				conv.ArgConv [ pos++ ] = g_strdup ("-f");
-				conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
-				conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFile);
-				conv.ArgConv [ pos++ ] = NULL;
+				
+				PtrTabArgs = filelc_AllocTabArgs();
+				pos = 3;
+				PtrTabArgs [ pos++ ] = g_strdup ("ogg123");
+				PtrTabArgs [ pos++ ] = g_strdup ("-d");
+				PtrTabArgs [ pos++ ] = g_strdup ("wav");
+				PtrTabArgs [ pos++ ] = g_strdup ("-f");
+				PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
+				PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFile);
+				PtrTabArgs [ pos++ ] = NULL;
 
-				conv_to_convert (FALSE, OGG123_OGG_TO_WAV, "OGG123_OGG_TO_WAV CONVERSION Ogg vers Wav");
-				filelc_get_command_line_remove ();
+				conv_to_convert( PtrTabArgs, FALSE, OGG123_OGG_TO_WAV, "OGG123_OGG_TO_WAV CONVERSION Ogg vers Wav");
+				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 
 				normalise.ElementActif ++;
 			}
@@ -968,23 +990,24 @@ void normalise_PEAK_RMS_GROUP_wav_ogg_mp3 (void)
 		while (List) {
 			if (NULL != (IndiFix = (INDI_FIX *)List->data)) {
 				
-				pos = filelc_get_command_line_nice ();
-				conv.ArgConv [ pos++ ] = g_strdup ("mplayer");
-				conv.ArgConv [ pos++ ] = g_strdup ("-nojoystick");
-				conv.ArgConv [ pos++ ] = g_strdup ("-nolirc");
-				conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFile);
-				conv.ArgConv [ pos++ ] = g_strdup ("-ao");
-				conv.ArgConv [ pos++ ] = g_strdup ("pcm");
-				conv.ArgConv [ pos++ ] = g_strdup ("-ao");
-				conv.ArgConv [ pos++ ] = g_strdup_printf ("pcm:file=%s",IndiFix->NameFileCopieWav);
-				conv.ArgConv [ pos++ ] = g_strdup ("-af");
-				conv.ArgConv [ pos++ ] = g_strdup ("channels=2");
-				conv.ArgConv [ pos++ ] = g_strdup ("-srate");
-				conv.ArgConv [ pos++ ] = g_strdup ("44100");
-				conv.ArgConv [ pos++ ] = NULL;
+				PtrTabArgs = filelc_AllocTabArgs();
+				pos = 3;
+				PtrTabArgs [ pos++ ] = g_strdup ("mplayer");
+				PtrTabArgs [ pos++ ] = g_strdup ("-nojoystick");
+				PtrTabArgs [ pos++ ] = g_strdup ("-nolirc");
+				PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFile);
+				PtrTabArgs [ pos++ ] = g_strdup ("-ao");
+				PtrTabArgs [ pos++ ] = g_strdup ("pcm");
+				PtrTabArgs [ pos++ ] = g_strdup ("-ao");
+				PtrTabArgs [ pos++ ] = g_strdup_printf ("pcm:file=%s",IndiFix->NameFileCopieWav);
+				PtrTabArgs [ pos++ ] = g_strdup ("-af");
+				PtrTabArgs [ pos++ ] = g_strdup ("channels=2");
+				PtrTabArgs [ pos++ ] = g_strdup ("-srate");
+				PtrTabArgs [ pos++ ] = g_strdup ("44100");
+				PtrTabArgs [ pos++ ] = NULL;
 
-				conv_to_convert (FALSE, MPLAYER_MP3_TO_WAV, "MPLAYER_MP3_TO_WAV");
-				filelc_get_command_line_remove ();
+				conv_to_convert( PtrTabArgs, FALSE, MPLAYER_MP3_TO_WAV, "MPLAYER_MP3_TO_WAV");
+				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 				
 				normalise.ElementActif ++;
 			}
@@ -999,15 +1022,16 @@ void normalise_PEAK_RMS_GROUP_wav_ogg_mp3 (void)
 		normalise_set_mess ("PEAK/GROUPE: Chercher la moyenne Peak");
 		
 		/* CHERCHER LA MOYENNE PEAK */
-		pos = filelc_get_command_line_nice ();
-		conv.ArgConv [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
-		conv.ArgConv [ pos++ ] = g_strdup ("-n");
+		PtrTabArgs = filelc_AllocTabArgs();
+		pos = 3;
+		PtrTabArgs [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
+		PtrTabArgs [ pos++ ] = g_strdup ("-n");
 
 		/* Creation liste WAV */
 		List = g_list_first (normalise.ListPeakGroupWav);
 		while (List) {
 			if ((IndiFix = (INDI_FIX *)List->data)) {
-				conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
+				PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
 			}
 			List = g_list_next(List);
 		}
@@ -1015,7 +1039,7 @@ void normalise_PEAK_RMS_GROUP_wav_ogg_mp3 (void)
 		List = g_list_first (normalise.ListPeakGroupOgg);
 		while (List) {
 			if ((IndiFix = (INDI_FIX *)List->data)) {
-				conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
+				PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
 			}
 			List = g_list_next(List);
 		}
@@ -1023,29 +1047,30 @@ void normalise_PEAK_RMS_GROUP_wav_ogg_mp3 (void)
 		List = g_list_first (normalise.ListPeakGroupMp3);
 		while (List) {
 			if ((IndiFix = (INDI_FIX *)List->data)) {
-				conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
+				PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
 			}
 			List = g_list_next(List);
 		}
-		conv.ArgConv [ pos++ ] = NULL;
+		PtrTabArgs [ pos++ ] = NULL;
 		
 		/* Chercher la moyenne PEAK */
-		conv_to_convert (FALSE, NORMALISE_GET_LEVEL, "NORMALISE_GET_LEVEL -> PEAK/GROUP");
-		filelc_get_command_line_remove ();
+		conv_to_convert( PtrTabArgs, FALSE, NORMALISE_GET_LEVEL, "NORMALISE_GET_LEVEL -> PEAK/GROUP");
+		PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 		
 		/* APPLIQUER LA MOYENNE PEAK */
 
 		normalise_set_mess ("PEAK/GROUPE: Normalise Wav");
 		
-		pos = filelc_get_command_line_nice ();
-		conv.ArgConv [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
-		conv.ArgConv [ pos++ ] = g_strdup_printf ("--gain=%fdB", conv.value_PEAK_RMS_GROUP_ARGS);
+		PtrTabArgs = filelc_AllocTabArgs();
+		pos = 3;
+		PtrTabArgs [ pos++ ] = g_strdup (prginit_get_name (NMR_normalize));
+		PtrTabArgs [ pos++ ] = g_strdup_printf ("--gain=%fdB", conv.value_PEAK_RMS_GROUP_ARGS);
 		
 		/* Creation liste WAV */
 		List = g_list_first (normalise.ListPeakGroupWav);
 		while (List) {
 			if ((IndiFix = (INDI_FIX *)List->data)) {
-				conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
+				PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
 				if (*IndiFix->EtatTrash == FILE_TRASH_OK) *IndiFix->EtatTrash = FILE_TRASH_VERIF_OK;
 			}
 			List = g_list_next(List);
@@ -1054,7 +1079,7 @@ void normalise_PEAK_RMS_GROUP_wav_ogg_mp3 (void)
 		List = g_list_first (normalise.ListPeakGroupOgg);
 		while (List) {
 			if ((IndiFix = (INDI_FIX *)List->data)) {
-				conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
+				PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
 				if (*IndiFix->EtatTrash == FILE_TRASH_OK) *IndiFix->EtatTrash = FILE_TRASH_VERIF_OK;
 			}
 			List = g_list_next(List);
@@ -1063,16 +1088,16 @@ void normalise_PEAK_RMS_GROUP_wav_ogg_mp3 (void)
 		List = g_list_first (normalise.ListPeakGroupMp3);
 		while (List) {
 			if ((IndiFix = (INDI_FIX *)List->data)) {
-				conv.ArgConv [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
+				PtrTabArgs [ pos++ ] = g_strdup (IndiFix->NameFileCopieWav);
 				if (*IndiFix->EtatTrash == FILE_TRASH_OK) *IndiFix->EtatTrash = FILE_TRASH_VERIF_OK;
 			}
 			List = g_list_next(List);
 		}
-		conv.ArgConv [ pos++ ] = NULL;
+		PtrTabArgs [ pos++ ] = NULL;
 		
 		/* Normalisation */
-		conv_to_convert (FALSE, NORMALISE_EXEC, "NORMALISE_EXEC Wav -> PEAK/GROUP");
-		filelc_get_command_line_remove ();
+		conv_to_convert( PtrTabArgs, FALSE, NORMALISE_EXEC, "NORMALISE_EXEC Wav -> PEAK/GROUP");
+		PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 
 		normalise.ElementActif ++;
 	}
@@ -1116,9 +1141,9 @@ void normalise_PEAK_RMS_GROUP_wav_ogg_mp3 (void)
 					param_filelc.num_track             = NULL;
 					param_filelc.PtrStrBitrate         = NULL;
 
-					filelc_get_command_line (&param_filelc);
-					conv_to_convert (FALSE, OGGENC_WAV_TO_OGG, "OGGENC_WAV_TO_OGG");
-					filelc_get_command_line_remove ();
+					PtrTabArgs = filelc_get_command_line (&param_filelc);
+					conv_to_convert( PtrTabArgs, FALSE, OGGENC_WAV_TO_OGG, "OGGENC_WAV_TO_OGG");
+					PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 
 					g_unlink (IndiFix->NameFileCopieWav);
 
@@ -1144,9 +1169,9 @@ void normalise_PEAK_RMS_GROUP_wav_ogg_mp3 (void)
 					param_filelc.num_track            = NULL;
 					param_filelc.PtrStrBitrate        = NULL;
 
-					filelc_get_command_line (&param_filelc);
-					conv_to_convert (FALSE, LAME_WAV_TO_MP3, "LAME_WAV_TO_MP3");
-					filelc_get_command_line_remove ();
+					PtrTabArgs = filelc_get_command_line (&param_filelc);
+					conv_to_convert( PtrTabArgs, FALSE, LAME_WAV_TO_MP3, "LAME_WAV_TO_MP3");
+					PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 
 					g_unlink (IndiFix->NameFileCopieWav);
 
