@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2012 by Claude Bulin
+ *  copyright : (C) 2003 - 2013 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -106,11 +106,10 @@ gchar *SplitCue_read_cue_file (gchar *p_pathname)
 	gint		IndicePoints = -1;
 	gint		FileTimeSec;
 	gboolean	BoolResultOk;
-	
+
 	// 
 	// TEST LA COHERENCE DU FICHIER CUE
 	// 
-	
 	if (NULL == (fp = fopen (p_pathname, "r"))) {
 		wininfo_create (
 			WindMain,
@@ -205,40 +204,47 @@ gchar *SplitCue_read_cue_file (gchar *p_pathname)
 	
 	// 
 	// LECTURE DES INFOS DU FICHIER
-	// 
-	
+	// 	
 	FileTimeSec = tagswav_get_time_sec (PathNameSong);
 	
-	fp = fopen (p_pathname, "r");
-	while (fgets (buf, MAX_CARS_SPLIT_CUE_FILE, fp) != NULL) {
+	if( NULL != ( fp = fopen( p_pathname, "r" )) ) {
+
+		while (fgets (buf, MAX_CARS_SPLIT_CUE_FILE, fp) != NULL) {
+		
+			if (strstr (buf, "TRACK ")) {
+				// g_print("TRACK ->%s", buf);
+			}
+		
+			// DEBUT
+		
+			else if (strstr (buf, "INDEX 01")) {
+				
+				IndicePoints ++;
+				
+				VarSplit.Selecteur [ IndicePoints ] . Nmr             = IndicePoints;
+				VarSplit.Selecteur [ IndicePoints ] . BeginPaint      = SplitCue_get_time_in_sec (buf);
+				VarSplit.Selecteur [ IndicePoints ] . PercentBegin    = ((gdouble)VarSplit.Selecteur [ IndicePoints ] . BeginPaint / (gdouble)FileTimeSec) * 100.0;
+			} 
+		
+			// FIN
+		
+			else if (strstr (buf, "INDEX 00")) {
+				
+				// SOLVED Sun, 03 Feb 2013 22:17:05 +0100
+				if( -1 == IndicePoints ) IndicePoints = 0;
+				
+				VarSplit.Selecteur [ IndicePoints ] . Nmr             = IndicePoints;
+				VarSplit.Selecteur [ IndicePoints ] . EndPaint        = SplitCue_get_time_in_sec (buf);
+				VarSplit.Selecteur [ IndicePoints ] . PercentEnd      = ((gdouble)VarSplit.Selecteur [ IndicePoints ] . EndPaint / (gdouble)FileTimeSec) * 100.0;
+			}
+		
+			else if (strstr (buf, "TITLE ")) {
+				// g_print("TITLE ->%s", buf);
+			} 
 		
-		if (strstr (buf, "TRACK ")) {
-			// g_print("TRACK ->%s", buf);
 		}
-		
-		// DEBUT
-		
-		else if (strstr (buf, "INDEX 01")) {
-			IndicePoints ++;
-			VarSplit.Selecteur [ IndicePoints ] . Nmr             = IndicePoints;
-			VarSplit.Selecteur [ IndicePoints ] . BeginPaint      = SplitCue_get_time_in_sec (buf);
-			VarSplit.Selecteur [ IndicePoints ] . PercentBegin    = ((gdouble)VarSplit.Selecteur [ IndicePoints ] . BeginPaint / (gdouble)FileTimeSec) * 100.0;
-		} 
-		
-		// FIN
-		
-		else if (strstr (buf, "INDEX 00")) {
-			VarSplit.Selecteur [ IndicePoints ] . Nmr             = IndicePoints;
-			VarSplit.Selecteur [ IndicePoints ] . EndPaint        = SplitCue_get_time_in_sec (buf);
-			VarSplit.Selecteur [ IndicePoints ] . PercentEnd      = ((gdouble)VarSplit.Selecteur [ IndicePoints ] . EndPaint / (gdouble)FileTimeSec) * 100.0;
-		}
-		
-		else if (strstr (buf, "TITLE ")) {
-			// g_print("TITLE ->%s", buf);
-		} 
-		
+		fclose (fp);
 	}
-	fclose (fp);
 	
 	// AJUSTER LE DEBUT
 	VarSplit.Selecteur [ 0 ] . BeginPaint         = 1;
