@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright :( C) 2003 - 2012 by Claude Bulin
+ *  copyright :( C) 2003 - 2013 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -33,6 +33,13 @@
 #include "file.h"
 
 
+typedef enum {
+	TAG_WAVE_IS_NONE = 0,
+	TAG_WAVE_IS_FMT,
+	TAG_WAVE_IS_BEXT
+} TAG_WAV_IS_FMT_BEXT;
+
+
 typedef struct {  
 
 	struct {  
@@ -40,7 +47,9 @@ typedef struct {
 		guint32 ChunkSize;	//(  4 octets) : taille du fichier entier en octets( sans compter les 8 octets de ce champ et le champ précédent CunkID  
 		char	Format[4];	//(  4 octets) : correspond au format du fichier donc ici, contient les lettres "WAVE" car fichier est au format wave  
 	} RIFF;  
-
+	
+	TAG_WAV_IS_FMT_BEXT	TagWavIsFmtBext;
+	
 	struct {  
 		char	Subchunk1ID[4];	//(  4 octets) : contient les lettres "fmt " pour indiquer les données à suivre décrivent le format des données audio  
 		guint32 Subchunk1Size;	//(  4 octets) : taille en octet des données à suivre( qui suivent cette variable) 16 Pour un fichier PCM  
