@@ -225,6 +225,7 @@ axml_chunk;
 */
 gboolean tagswav_read_file (gchar *wave_file, WAVE *WaveHeader)
 {
+/*
 	gint	seek_bext = -1;
 	gint	seek_qlty = -1;
 	gint	seek_levl = -1;
@@ -236,12 +237,7 @@ gboolean tagswav_read_file (gchar *wave_file, WAVE *WaveHeader)
 	
 	tagswav_init (WaveHeader);
 	
-	if (NULL == (WaveHeader->file = fopen(wave_file, "rb"))) { 
-	
-		if( TRUE == OptionsCommandLine.BoolVerboseMode )
-			g_print ("\nERREUR: fichier WAV [ %s ] introuvable\n", wave_file);  
-		return (FALSE);
-	}
+	if (NULL == (WaveHeader->file = fopen(wave_file, "rb"))) return (FALSE);
 	
 	seek_fmt  = tagswav_get_pos( wave_file, 'f', 'm', 't', ' ' );
 	seek_data = tagswav_get_pos( wave_file, 'd', 'a', 't', 'a' );
@@ -310,7 +306,51 @@ gboolean tagswav_read_file (gchar *wave_file, WAVE *WaveHeader)
 		g_print ("\tseek_data = %d\n", seek_data );
 	}
 	return( TRUE );
+*/
+	gint	seek_fmt = -1;
+	gint	seek_data = -1;
+ 	gint	n_read;
 	
+	seek_fmt  = tagswav_get_pos( wave_file, 'f', 'm', 't', ' ' );
+	seek_data = tagswav_get_pos( wave_file, 'd', 'a', 't', 'a' );
+	if( -1 == seek_fmt || -1 == seek_data ) return( FALSE );
+	
+	if( NULL == ( WaveHeader->file = fopen( wave_file, "rb" ))) return (FALSE);
+	// LECTURE ENTETE
+	n_read = fread( &WaveHeader->RIFF.ChunkID, 4, 1, WaveHeader->file );		// RIFF
+	n_read = fread( &WaveHeader->RIFF.ChunkSize, 4, 1, WaveHeader->file );		// taille du fichier entier en octets (sans compter les 8 octets de ce champ et le champ précédent
+	n_read = fread( &WaveHeader->RIFF.Format, 4, 1, WaveHeader->file );		// WAVE
+	n_read = fread( &WaveHeader->FMT.Subchunk1ID, 4, 1, WaveHeader->file );		// 'fmt ' | 'bext'
+	
+	if( 0 == strncmp( WaveHeader->FMT.Subchunk1ID, "fmt ", 4 )) {
+		
+		WaveHeader->TagWavIsFmtBext = TAG_WAVE_IS_FMT;		
+	}
+	else {
+		WaveHeader->TagWavIsFmtBext = TAG_WAVE_IS_BEXT;
+		
+		n_read = fseek( WaveHeader->file, seek_fmt + 4, SEEK_SET );
+	}
+	
+	// FMT
+	n_read = fread( &WaveHeader->FMT.Subchunk1Size, 4, 1, WaveHeader->file );	// taille en octet des données à suivre
+	n_read = fread( &WaveHeader->FMT.AudioFormat, 2, 1, WaveHeader->file );		// format de compression (une valeur autre que 1 indique une compression) 
+	n_read = fread( &WaveHeader->FMT.NumChannels, 2, 1, WaveHeader->file );		// nombre de canaux
+	n_read = fread( &WaveHeader->FMT.SampleRate, 4, 1, WaveHeader->file );		// fréquence d'échantillonage (nombre d'échantillons par secondes) 
+	n_read = fread( &WaveHeader->FMT.ByteRate, 4, 1, WaveHeader->file );		// nombre d'octects par secondes
+	n_read = fread( &WaveHeader->FMT.Blockalign, 2, 1, WaveHeader->file );		// nombre d'octects pour coder un échantillon
+	n_read = fread( &WaveHeader->FMT.BitsPerSample, 2, 1, WaveHeader->file );	// nombre de bits pour coder un échantillon
+	
+	// DATA
+	n_read = fseek( WaveHeader->file, seek_data, SEEK_SET );
+	n_read = fread( &WaveHeader->DATA.Subchunk2ID, 4, 1, WaveHeader->file );
+	n_read = fread( &WaveHeader->DATA.Subchunk2Size, 4, 1, WaveHeader->file );
+	
+	if( n_read );
+	tagswav_print_header( wave_file,  WaveHeader );
+	
+	return( TRUE );
+
 }
 // 
 // 
@@ -408,7 +448,10 @@ INFO_WAV *tagswav_get_info (gchar *namefile)
 	m = sec % 60; sec /= 60;
 	if (sec > 0) ptrinfo->time = g_strdup_printf ("%02d:%02d:%02d", sec, m, s);
 	else         ptrinfo->time = g_strdup_printf ("%02d:%02d", m, s);
-		
+	
+	// 'fmt ', 'bext', 'qlty', 'levl', 'link','axml'
+	ptrinfo->BoolBwf = WaveHeader.TagWavIsFmtBext == TAG_WAVE_IS_FMT ? FALSE : TRUE;
+	
 	// mode
 	ptrinfo->voie    = g_strdup_printf ("%d", WaveHeader.FMT.NumChannels);
 	ptrinfo->NewVoie = g_strdup_printf ("%d", WaveHeader.FMT.NumChannels);
