@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2012 by Claude Bulin
+ *  copyright : (C) 2003 - 2013 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -104,9 +104,6 @@ void translate_xcfa (void)
 	{ _("<b> Normalise: </b>") },
 	{ _("<b> Choix niveau dBFS: </b>") },
 	{ _(" Fichiers ") },
-	{ _("<b>Quantification</b>") },
-	{ _("<b>Voie</b>") },
-	{ _("<b> Frequence - Hertz </b>") },
 	{ _("Appliquer les modifications") },
 	{ _(" Wav ") },
 	{ _("Appliquer") },
@@ -319,6 +316,7 @@ void translate_xcfa (void)
 	{ _("<b> Informations </b>") },
 	{ _(" Application externes ") },
 	{ _("<i>parametres:</i>") },
+	{ _("\n konqueror : newTab\n iceweasel : -new-window -new-tab \n") },
 	{ _("<b>Navigateur</b>") },
 	{ _("<i>parametres:</i>") },
 	{ _("<b>Lecteurs audio</b>") },
