@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2012 by Claude Bulin
+ *  copyright : (C) 2003 - 2013 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -85,8 +85,7 @@ void web_call_navigator (void)
 
 	if ((pid = fork ()) == 0) {
 		/*
-		kfmclient newTab http://www.xcfa.tuxfamily.org &
-		*/
+		// kfmclient newTab http://www.xcfa.tuxfamily.org &
 		if (strcmp (VarWeb.Navigateur, "konqueror") == 0) {
 			execlp ("kfmclient",
 				"kfmclient",
@@ -94,21 +93,26 @@ void web_call_navigator (void)
 				VarWeb.NameNavi,
 				NULL);
 		}
-		if (strcmp (VarWeb.Navigateur, "opera") == 0) {
+		else if (strcmp (VarWeb.Navigateur, "opera") == 0) {
 			execlp (VarWeb.Navigateur,
 				VarWeb.Navigateur,
 				VarWeb.NameNavi,
 				NULL);
 		}
-		else {
-			/*
-			-new-window URL
-				Open URL in a new window in an already running Firefox  process.
-				-new-tab URL Open URL in a new tab in an already running Firefox process.
-			EXEMPLE:
-				firefox -new-window -new-tab http:/www.google.fr
-			*/
-			// g_print("%s -new-window -new-tab %s\n", VarWeb.Navigateur,VarWeb.NameNavi);
+		else if (strcmp (VarWeb.Navigateur, "midori") == 0) {
+			execlp (VarWeb.Navigateur,
+				VarWeb.Navigateur,
+				VarWeb.NameNavi,
+				NULL);
+		}
+		else if( (strcmp (VarWeb.Navigateur, "firefox") == 0) ||
+			  (strcmp (VarWeb.Navigateur, "iceweasel") == 0) ) {
+
+			// -new-window URL
+			// 	Open URL in a new window in an already running Firefox  process.
+			// 	-new-tab URL Open URL in a new tab in an already running Firefox process.
+			// EXEMPLE:
+			// 	firefox -new-window -new-tab http:/www.google.fr
 			execlp (VarWeb.Navigateur,
 				VarWeb.Navigateur,
 				"-new-window",
@@ -116,6 +120,32 @@ void web_call_navigator (void)
 				VarWeb.NameNavi,
 				NULL);
 		}
+		else {
+			gchar	Str [ 200 ];
+			
+			Str [ 0 ] = '\0';
+			if( NULL != Config.StringParamNameNavigateur && *Config.StringParamNameNavigateur != '\0' ) {
+				strncpy( Str, Config.StringParamNameNavigateur, 180 );
+			}
+			execlp (VarWeb.Navigateur,
+				VarWeb.Navigateur,
+				VarWeb.NameNavi,
+				Str,
+				NULL);
+		}
+		*/
+		gchar	Str [ 200 ];
+		
+		Str [ 0 ] = '\0';
+		if( NULL != Config.StringParamNameNavigateur && *Config.StringParamNameNavigateur != '\0' ) {
+			strncpy( Str, Config.StringParamNameNavigateur, 180 );
+		}
+		execlp (VarWeb.Navigateur,
+			VarWeb.Navigateur,
+			VarWeb.NameNavi,
+			Str,
+			NULL);
+		
 		_exit (0);
 	}
 }
